/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02835
 |       NATIONAL PREGNANCY AND HEALTH SURVEY: DRUG USE AMONG WOMEN
 |                      DELIVERING LIVE BIRTHS, 1992
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02835-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE int_time  9995='(9995) ERROR IN DATA ENTRY OR BY INTERVIEWER'
                  9996='(9996) NOT INTERVIEWED' 9999='(9999) NOT ASCERTAINED' ;
  VALUE iaq_1fff  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_boxa  1='(1) Q1 CONTAINS DATE, OR EDC/#WKS GESTATION'
                  2='(2) OTHERWISE (ANSWER 1A)' 6='(6) NOT INTERVIEWED' ;
  VALUE iaq_1a    1='(1) ON TIME' 2='(2) LATE' 3='(3) EARLY' 6='(6) NOT INTERVIEWED'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_1b    0='(0) LESS THAN ONE(1) WEEK' 96='(96) NOT INTERVIEWED' 97='(97) INAP.'
                  98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_4fff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_5fff  995='(995) DIDNT HAVE A PERIOD' 996='(996) NOT INTERVIEWED'
                  998='(998) DONT KNOW' 999='(999) NOT ASCERTAINED' ;
  VALUE iaq5flag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iaq_6fff  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq6flag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iaq_day   1='(1) BEGINNING (1 -10)' 2='(2) MIDDLE (11 -20)'
                  3='(3) END OF MONTH (21-31)' 6='(6) NOT INTERVIEWED' 7='(7) INAP.'
                  8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_7fff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_8fff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq8flag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iaq_9fff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_10ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_11ff  1='(1) PRIVATE DOCTORS OR NURSE MIDWIFES OFFI'
                  2='(2) COUNTY OR CITY HEALTH DEPARTMENT'
                  3='(3) COMMUNITY OR NEIGHBORHOOD HEALTH CENTER'
                  4='(4) HMO/HEALTH MAINTENANCE ORGANIZATION'
                  5='(5) CLINIC AT WORK OR SCHOOL' 6='(6) CLINIC IN A HOSPITAL'
                  7='(7) EMERGENCY ROOM IN A HOSPITAL'
                  8='(8) NAME OF PLACE GIVEN, TYPE NOT SPECIFIED'
                  9='(9) CLINIC, NOT OTHERWISE SPECIFIED'
                  10='(10) OTHER PLACE (SPECIFY) - (MAKE PROBLEM CA'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_12a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12g   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12h   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_12hs  1='(1) STRESS TEST, NON-STRESS TEST, FETAL MONI'
                  2='(2) CHILDBIRTH CLASSES, LAMAZE CLASSES,'
                  3='(3) OTHER SERVICES (MAKE PROBLEM CARD)' 96='(96) NOT INTERVIEWED'
                  97='(97) INAP.' 98='(98) DONT KNOW' ;
  VALUE iaq_13a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_13b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_13c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_13d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_13ds  1='(1) REASON(S) GIVEN (MAKE PROBLEM CARD)'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW' ;
  VALUE iaq_14ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_15ff  996='(996) NOT INTERVIEWED' 998='(998) DONT KNOW' 999='(999) NOT ASCERTAINED' ;
  VALUE iaq_16ff  996='(996) NOT INTERVIEWED' 998='(998) DONT KNOW' 999='(999) NOT ASCERTAINED' ;
  VALUE iaq_17ft  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_17in  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_18a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_18b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_18c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_18d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_18ds  1='(1) ASTHMA' 2='(2) LOW BLOOD PRESSURE' 3='(3) ANEMIA'
                  4='(4) OTHER CONDITIONS (MAKE PROBLEM CARD)'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW' ;
  VALUE iaq_19a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_19b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_19c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_21a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_21b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_21c   1='(1) YES' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_21d   1='(1) YES' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_21e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_20sp  1='(1) OTHER DISEASE NAMED (MAKE PROBLEM CARD)'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW NAME' ;
  VALUE iaq_21f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_22ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_22sp  1='(1) VAGINAL/YEAST INFECTIONS' 2='(2) RESPIRATORY INFECTIONS'
                  3='(3) OTHER REASONS (MAKE PROBLEM CARD)' 96='(96) NOT INTERVIEWED'
                  97='(97) INAP.' 98='(98) DONT KNOW NAME OF ILLNESS' ;
  VALUE iaq_23ff  0='(0) NONE' 7='(7) 7 OR MORE' 96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_24a   0='(0) NO LIVE BIRTHS' 7='(7) 7 OR MORE' 96='(96) NOT INTERVIEWED'
                  97='(97) INAP.' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_24b   7='(7) 7 OR MORE' 96='(96) NOT INTERVIEWED' 97='(97) INAP.'
                  98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_boxb  1='(1) Q24A 7 Q24B IS EQUAL TO Q23'
                  2='(2) Q24A 7 Q24B IS NOT EQUAL TO Q23' 6='(6) NOT INTERVIEWED'
                  7='(7) INAP.' ;
  VALUE iaq_24c   7='(7) 7 OR MORE' 96='(96) NOT INTERVIEWED' 97='(97) INAP.'
                  98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_24d   96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_24e   96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_25ff  1='(1) LIVEBIRTH' 2='(2) MISCARRIAGE' 3='(3) STILLBIRTH'
                  4='(4) INDUCED ABORTION' 5='(5) ECTOPIC PREGNANCY'
                  6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_26ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq26flg  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iaq_boxc  1='(1) Q24A IS EQUAL TO 00' 2='(2) Q24A IS NOT EQUAL TO 00'
                  6='(6) NOT INTERVIEWED' 7='(7) INAP.' ;
  VALUE iaq_cntr  96='(96) NOT INTERVIEWED' 97='(97) INAP.' ;
  VALUE iaq_wg    99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb0f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb1f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb2f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb3f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb4f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW' ;
  VALUE iq27lb5f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb6f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb7f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb8f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27lb9f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz0f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz1f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz2f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz3f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz4f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz5f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz6f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz7f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz8f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq27oz9f  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2801ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2802ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2803ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2804ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2805ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2806ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2807ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2808ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2809ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2810ff  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iq2901ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2902ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2903ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2904ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2905ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2906ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2907ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2908ff  2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2909ff  2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iq2910ff  1='(1) YES' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_31ff  1='(1) MARRIED' 2='(2) NOT MARRIED BUT LIVING WITH A PARTNER OR'
                  3='(3) WIDOWED' 4='(4) DIVORCED' 5='(5) SEPARATED' 6='(6) NEVER MARRIED'
                  96='(96) NOT INTERVIEWED' ;
  VALUE iaq_32ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_33ff  1='(1) PUERTO RICAN' 2='(2) CUBAN'
                  3='(3) MEXICAN, CHICANA, MEXICAN AMERICAN'
                  4='(4) CENTRAL OR SOUTH AMERICAN' 5='(5) OTHER SPANISH'
                  6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_34ff  1='(1) WHITE' 2='(2) BLACK' 3='(3) ASIAN OR PACIFIC ISLANDER'
                  4='(4) ESKIMO, ALEUT OR AMERICAN INDIAN' 6='(6) NOT INTERVIEWED'
                  8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_35ff  0='(0) 7TH GRADE OR LESS' 8='(8) 8TH GRADE'
                  9='(9) 9TH GRADE (HIGH SCHOOL)' 10='(10) 10TH GRADE (HIGH SCHOOL)'
                  11='(11) 11TH GRADE (HIGH SCHOOL)' 12='(12) 12TH GRADE (HIGH SCHOOL)'
                  13='(13) 1 YR. COLLEGE' 14='(14) 2 YRS. COLLEGE' 15='(15) 3 YRS. COLLEGE'
                  16='(16) 4 YRS. COLLEGE' 17='(17) GRAD/PROFESSIONAL SCHOOL'
                  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_36ff  0='(0) NONE' 94='(94) 1 TO 5 MONTHS, 1 SEMESTER' 95='(95) 6 TO 11 MONTHS'
                  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_boxd  1='(1) Q35 IS 12 OR GREATER' 2='(2) Q35 IS LESS THAN 12'
                  6='(6) NOT INTERVIEWED' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_37ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_38ff  1='(1) WORKING' 2='(2) HAD A JOB BUT NOT WORKING FOR SOME REASO'
                  3='(3) UNEMPLOYED' 4='(4) FULL TIME HOMEMAKER' 5='(5) GOING TO SCHOOL'
                  6='(6) SOMETHING ELSE (SPECIFY) - MAKE PROBLEM'
                  96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_39ff  1='(1) PART - TIME' 2='(2) FULL - TIME' 6='(6) NOT INTERVIEWED'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_40ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_41ff  1='(1) SUBJECT LIVED ALONE' 96='(96) NOT INTERVIEWED' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_42ff  0='(0) NONE ARE FAMILY MEMBERS' 96='(96) NOT INTERVIEWED' 97='(97) INAP.'
                  98='(98) DONT KNOW' 99='(99) NOT ASCERTAINED' ;
  VALUE iaq_43a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43g   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43h   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_43i   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_boxe  1='(1) Q41 IS EQUAL TO 01' 2='(2) Q41 IS NOT EQUAL TO 01'
                  6='(6) NOT INTERVIEWED' ;
  VALUE iaq_44ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_45ff  1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_boxf  1='(1) S LIVED ONLY WITH NON-FAMILY MEMBERS (Q4'
                  2='(2) S LIVED WITH FAMILY MEMBERS (Q42 NOT 00)'
                  6='(6) NOT INTERVIEWED' 7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_46ff  1='(1) $0 TO $4999' 3='(3) $5,000 TO $6,300 $97 TO $120'
                  4='(4) $6,301 TO $8,450 $121 TO $160'
                  5='(5) $8,451 TO $10,600 $161 TO $200'
                  6='(6) $10,601 TO $12,700 $201 TO $245'
                  7='(7) $12,701 TO $14,850 $246 TO $285'
                  8='(8) $14,851 TO $17,000 $286 TO $325'
                  9='(9) $17,001 TO $19,000 $326 TO $370'
                  10='(10) $19,001 TO $21,300 $371 TO $410'
                  11='(11) $21,301 TO $25,000 $411 TO $480'
                  12='(12) $25,001 TO $30,000 $481 TO $576'
                  13='(13) $30,001 TO $40,000 $577 TO $769'
                  14='(14) $40,001 TO $50,000 $770 TO $961'
                  15='(15) $50,001 TO $75,000 $962 TO $1441'
                  16='(16) $75,001 OR MORE $1,442 OR MORE' 17='(17) REFUSED'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_boxg  2='(2) ALL PEOPLE ARE RELATED (Q42 IS ONE(1) LE'
                  3='(3) NON - FAMILY MEMBERS IN HOUSEHOLD' 6='(6) NOT INTERVIEWED'
                  7='(7) INAP.' ;
  VALUE iaq_47ff  1='(1) $0-$4999/YR' 3='(3) $5,000-$6,300/YR; $97-$120/WK'
                  4='(4) $6,301-$8,450/YR; $121-$160/WK'
                  5='(5) $8,451-$10,600/YR; $161-$200/WK'
                  6='(6) $10,601-$12,700/YR; $201-$245/WK'
                  7='(7) $12,701-$14,850/YR; $246-$285/WK'
                  8='(8) $14,851-$17,000/YR; $286-$325/WK'
                  9='(9) $17,001-$19,000/YR; $326-$370/WK'
                  10='(10) $19,001-$21,300/YR; $371-$410/WK'
                  11='(11) $21,301-$25,000/YR; $411-$480/WK'
                  12='(12) $25,001-$30,000/YR; $481-$576/WK'
                  13='(13) $30,001-$40,000/YR; $577-$769/WK'
                  14='(14) $40,001-$50,000/YR; $770-$961/WK'
                  15='(15) $50,001-$75,000/YR; $962-$1441/WK'
                  16='(16) $75,001+/YR; $1,442+/WK' 17='(17) REFUSED'
                  96='(96) NOT INTERVIEWED' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE iaq_48ff  1='(1) YES' 2='(2) NO' 3='(3) PENDING' 6='(6) NOT INTERVIEWED'
                  8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE iaq_49ff  995='(995) COVERED ON MOTHERS CARD' 996='(996) NOT INTERVIEWED'
                  997='(997) NOT APPLICABLE' 998='(998) DONT KNOW' 999='(999) NOT ASCERTAINED' ;
  VALUE iaq49flg  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iaq_50a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50am  1='(1) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50bm  2='(2) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50cm  3='(3) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50dm  4='(4) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50em  5='(5) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_50fm  1='(1) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_boxh  1='(1) SUBJECT RECEIVED PRENATAL CARE (IF Q7 EQ'
                  2='(2) SUBJECT DID NOT RECEIVE PRENATAL CARE (I'
                  6='(6) NOT INTERVIEWED' ;
  VALUE iaq_51a   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51am  1='(1) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51b   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51bm  2='(2) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51c   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51cm  3='(3) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51d   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51dm  4='(4) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51e   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51em  5='(5) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51f   1='(1) YES' 2='(2) NO' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE iaq_51fm  1='(1) MAIN SOURCE' 6='(6) NOT INTERVIEWED' 7='(7) INAP.' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_time  9996='(9996) NOT INTERVIEWED' 9999='(9999) NOT ASCERTAINED' ;
  VALUE lang      1='(1) ENGLISH' 2='(2) SPANISH' 6='(6) NOT INTERVIEWED' ;
  VALUE iaq_d2ff  96='(96) NOT INTERVIEWED' ;
  VALUE agecalc   96='(96) NOT INTERVIEWED' 99='(99) NOT ASCERTAINED' ;
  VALUE newlbs    96='(96) NOT INTERVIEWED' 97='(97) INAP.' 99='(99) NOT ASCERTAINED' ;
  VALUE newozs    96='(96) NOT INTERVIEWED' 97='(97) INAP.' 99='(99) NOT ASCERTAINED' ;
  VALUE newgrams  9996='(9996) NOT INTERVIEWED' 9997='(9997) INAP.' 9999='(9999) NOT ASCERTAINED' ;
  VALUE iaq_ec    996='(996) NOT INTERVIEWED' 999='(999) NOT ASCERTAINED' ;
  VALUE infnum    1='(1) ONLY 1 INFANT, WEIGHT GIVEN ABOVE'
                  2='(2) TWINS, SECOND WEIGHT BELOW'
                  3='(3) TRIPLETS, SECOND AND THIRD WEIGHTS BELOW'
                  4='(4) QUADRUPLETS, SECOND, THIRD, FOURTH WEIGH'
                  6='(6) NOT INTERVIEWED' ;
  VALUE newlbs2f  96='(96) NOT INTERVIEWED' 97='(97) NOT APPLICABLE'
                  99='(99) NOT ASCERTAINED' ;
  VALUE newozs2f  96='(96) NOT INTERVIEWED' 97='(97) NOT APPLICABLE'
                  99='(99) NOT ASCERTAINED' ;
  VALUE newgramf  9996='(9996) NOT INTERVIEWED' 9997='(9997) NOT APPLICABLE'
                  9999='(9999) NOT ASCERTAINED' ;
  VALUE ghflag    6='(6) NOT INTERVIEWED' 7='(7) INAP.' ;
  VALUE saq_1a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' 98='(98) DONT KNOW' ;
  VALUE saq_1b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' 98='(98) DONT KNOW' ;
  VALUE saq_1c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_1d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_2a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' 98='(98) DONT KNOW' ;
  VALUE saq_2b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' 98='(98) DONT KNOW' ;
  VALUE saq_2c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_2d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_3a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_3b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_3c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_3d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_4a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_4b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_4c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_4d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_5a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_5b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_5c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_5d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_6a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_6b    1='(1) EVERY DAY' 3='(3) 1 OR 2 DAYS A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_6c    6='(6) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_6d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_7a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_7b    1='(1) EVERY DAY' 3='(3) 1 OR 2 DAYS A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_7c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_7d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_8a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_8b    1='(1) EVERY DAY' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_8c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_8d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_9a    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_9b    1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_9c    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_9d    96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_10a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_10b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_10c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_10d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_11a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_11b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_11c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_11d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_12a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_12b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_12c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_12d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_13a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_13b   3='(3) 1 OR 2 DAYS A WEEK' 4='(4) LESS THAN ONE DAY A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_13c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_13d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_14a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_14b   3='(3) 1 OR 2 DAYS A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_14c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_14d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_15a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_15b   1='(1) EVERY DAY' 4='(4) LESS THAN ONE DAY A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_15c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_15d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_16a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_16b   3='(3) 1 OR 2 DAYS A WEEK' 4='(4) LESS THAN ONE DAY A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_16c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_16d   8='(8) DONT KNOW' 96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_17a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_17b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_17c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_17d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_18a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_18b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_18c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_18d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_19a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_19b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_19c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_19d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_20a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_20b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_20c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_20d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_21a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_21b   2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_21c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_21d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_22a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_22b   1='(1) EVERY DAY' 3='(3) 1 OR 2 DAYS A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_22c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_22d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_23a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_23b   1='(1) EVERY DAY' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_23c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_23d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_24a   2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_24b   6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_24c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_24d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' ;
  VALUE saq_25a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_25b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_25c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_25d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_26a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_26b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_26c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_26d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_27a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_27b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE saq_27c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_27d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_28a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_28b   3='(3) 1 OR 2 DAYS A WEEK' 4='(4) LESS THAN ONE DAY A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_28c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_28d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_29a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_29b   3='(3) 1 OR 2 DAYS A WEEK' 4='(4) LESS THAN ONE DAY A WEEK'
                  6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.' ;
  VALUE saq_29c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_29d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_30a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_30b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_30c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_30d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_31a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) INAP.'
                  8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_31b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_31c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_31d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_32a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 7='(7) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_32b   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 OR 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_32c   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_32d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_33a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_33b   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_33c   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 TO 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_33d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_33e   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_34a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_34b   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_34c   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 TO 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_34d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_34e   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_35a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_35b   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_35c   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 TO 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_35d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_35e   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_36a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_36b   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_36c   1='(1) EVERY DAY' 2='(2) 3 TO 6 DAYS A WEEK' 3='(3) 1 TO 2 DAYS A WEEK'
                  4='(4) LESS THAN ONE DAY A WEEK' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' 8='(8) DONT KNOW' 9='(9) NOT ASCERTAINED' ;
  VALUE saq_36d   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_36e   96='(96) NO SELF-ADMINISTERED QUEX' 97='(97) INAP.' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_37h   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_37i   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_38ff  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_39ff  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43a   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43b   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43c   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43d   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43e   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43f   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43g   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43h   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43i   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43j   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43k   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_43l   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_44ff  1='(1) WITHIN THE PAST YEAR'
                  2='(2) 1 OR MORE YEARS AGO, BUT LESS THAN 3 YEA'
                  3='(3) 3 OR MORE YEARS AGO' 4='(4) NEVER SMOKED'
                  6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) NOT SURE/DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_45ff  0='(0) NEVER USED MARIJUANA OR HASHISH'
                  96='(96) NO SELF-ADMINISTERED QUEX' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_46ff  1='(1) WITHIN THE PAST YEAR'
                  2='(2) 1 OR MORE YEARS AGO, BUT LESS THAN 3 YEA'
                  3='(3) 3 OR MORE YEARS AGO' 4='(4) NEVER USED MARIJUANA OR HASHISH'
                  6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE saq_47ff  0='(0) NEVER USED COCAINE IN ANY FORM'
                  96='(96) NO SELF-ADMINISTERED QUEX' 98='(98) DONT KNOW'
                  99='(99) NOT ASCERTAINED' ;
  VALUE saq_48ff  1='(1) WITHIN THE PAST YEAR'
                  2='(2) 1 OR MORE YEARS AGO, BUT LESS THAN 3 YEA'
                  3='(3) 3 OR MORE YEAR AGO' 4='(4) NEVER USED COCAINE'
                  6='(6) NO SELF-ADMINISTERED QUEX' 8='(8) DONT KNOW'
                  9='(9) NOT ASCERTAINED' ;
  VALUE flag44ff  1='(1) DATA INCONSISTENT' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE flag46ff  1='(1) DATA INCONSISTENT' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE flag48ff  1='(1) DATA INCONSISTENT' 6='(6) NO SELF-ADMINISTERED QUEX'
                  7='(7) INAP.' ;
  VALUE f_agegrf  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE f_raceth  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE iagegrpf  1='(1) UNDER 18 YEARS' 2='(2) 18-24 YEARS' 3='(3) 25-29 YEARS'
                  4='(4) 30-34 YEARS' 5='(5) 35-39 YEARS' 6='(6) 40+ YEARS' ;
  VALUE stratum   1='(1) METRO-HISPANIC' 2='(2) METRO-OTHER' 3='(3) NONMETRO' ;
  VALUE status    1='(1) ELIGIBLE RESPONDENT' 2='(2) ELIGIBLE NONRESPONDENT'
                  3='(3) NO RECORD IN WEIGHT FILE NONRESPONDENT'
                  4='(4) NONRESPONDENT, ELIGIBILITY STATUS UNKNOW' ;
  VALUE i_raceth  1='(1) WHITE' 2='(2) BLACK' 3='(3) HISPANIC' 4='(4) OTHER' ;
  VALUE numbabes  6='(6) NO RECORD IN WEIGHT FILE' ;
  VALUE nrfctr    0='(0) ZERO' 1='(1) EXACTLY ONE' 2='(2) MORE THAN ONE' 9='(9) BLANK' ;
  VALUE trmfctr   9.0000='(9.0000) BLANK' ;
  VALUE resp      1='(1) SAQ RESPONDENT' 2='(2) IAQ/NONSAQ RESPONDENT'
                  3='(3) NONRESPONDENT' 9='(9) BLANK = KNOWN INELGIBLE' ;
  VALUE alc3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE any3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cok3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coka3tup  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crk3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE done3tup  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE her3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE meth3tup  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thc3tup   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE income3f  1='(1) NONE - $14,850' 2='(2) $14,851 - $30,000' 3='(3) $30,001 +'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE gageflag  0='(0) NOT COMPUTED' 2='(2) COMPUTED' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE gage      96='(96) NO SELF-ADMINISTERED QUEX' ;
  VALUE cigpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alcpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crkpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE herpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE donepreg  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE methpreg  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE allpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cigever   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcever   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokever   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE racetflg  0='(0) NOT IMPUTED' 1='(1) IMPUTED' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE payflag   0='(0) NOT IMPUTED' 1='(1) IMPUTED' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE vstsflag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE metro     1='(1) METRO HOSPITAL' 2='(2) NON-METRO HOSPITAL'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE educflag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE emplflag  0='(0) NOT IMPUTED' 1='(1) IMPUTED' ;
  VALUE raceup    1='(1) WHITE' 2='(2) BLACK' 3='(3) HISPANIC' 4='(4) OTHER'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE age5ffff  1='(1) < 18 YEARS' 2='(2) 18 - 24 YEARS' 3='(3) 25 - 29 YEARS'
                  4='(4) 30 - 34 YEARS' 5='(5) 35 +YEARS'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE age3ffff  1='(1) < 25 YEARS' 2='(2) 25 - 29 YEARS' 3='(3) 30 + YEARS'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE payup     1='(1) PRIVATE' 2='(2) PUBLIC' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE maritalf  1='(1) MARRIED' 2='(2) NOT MARRIED' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE marita0f  1='(1) MARRIED' 2='(2) LIVING WITH PERSON'
                  3='(3) OTHER (WIDOWED,DIVORCED,SEPARATED)' 4='(4) NEVER MARRIED'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE educ      1='(1) < 12 YEARS' 2='(2) 12 YEARS' 3='(3) 13 - 15 YEARS'
                  4='(4) 16 + YEARS' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE educ2fff  1='(1) WORKING' 2='(2) NOT WORKING' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE empl1fff  1='(1) WORKING' 2='(2) NOT WORKING' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE empl2fff  1='(1) WORKING' 2='(2) UNEMPLOYED-LOOKING'
                  3='(3) UNEMPLOYED-NOT LOOKING' 4='(4) HOMEMAKER'
                  5='(5) ATTENDING SCHOOL' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokapreg  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE halpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE inhpreg   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ilseda    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE iltranq   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ilamphet  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ilanal    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ilpsy     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE seda      1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE tranq     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphet    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE anal      1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE scrpsy    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cigyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alcyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crkyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE heryr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE doneyr    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE methyr    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokayr    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE allyr     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alcig     1='(1) NONE' 2='(2) ALCOHOL ONLY' 3='(3) CIGARETTES ONLY'
                  4='(4) BOTH ALCOHOL AND CIGARETTES'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE any3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thc3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crk3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cok3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coka3m    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE her3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE done3m    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE meth3m    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig3m     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE any1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thc1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crk1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cok1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coka1t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE her1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE done1t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE meth1t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig1t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE any2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thc2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crk2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cok2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coka2t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE her2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE done2t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE meth2t    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig2t     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE any3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thc3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE crk3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cok3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coka3d    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE her3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE done3d    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE meth3d    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig3d     1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig1ts    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cig3tc    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc1ts    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE alc3tc    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE newvol    996='(996) NO SELF-ADMINISTERED QUEX' 999='(999) NOT ASCERTAINED' ;
  VALUE cokes     0='(0) NOT IMPUTED' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokeq     0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coken     6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphs     1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphq     0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphn     0='(0) NOT DONE' 2='(2) NEGATIVE' 3='(3) INSUFFICIENT VOLUME'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE methq     0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE methn     0='(0) NOT DONE' 2='(2) NEGATIVE' 3='(3) INSUFFICIENT VOLUME'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcs      0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcq      0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcn      0='(0) NOT DONE' 2='(2) NEGATIVE' 3='(3) INSUFFICIENT VOLUME'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ops       0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE codq      0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE codn      0='(0) NOT DONE' 2='(2) NEGATIVE' 3='(3) INSUFFICIENT VOLUME'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE morphq    0='(0) NOT DONE' 1='(1) POSITIVE' 2='(2) NEGATIVE'
                  3='(3) INSUFFICIENT VOLUME' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE morphn    0='(0) NOT DONE' 2='(2) NEGATIVE' 3='(3) INSUFFICIENT VOLUME'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphet3d  1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE anal3d    1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE ameth3d   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE hanal3d   1='(1) YES' 2='(2) NO' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thctest   1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE coketest  1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE amphtest  1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE optest    1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE anytest   1='(1) POSITIVE' 2='(2) NEGATIVE' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE thcrt     1='(1) REPORTED USE OR POSITIVE TEST RESULT'
                  2='(2) NO REPORTED USE AND NEGATIVE OR MISSING'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE cokert    1='(1) REPORTED USE OR POSITIVE TEST RESULT'
                  2='(2) NO REPORTED USE AND NEGATIVE OR MISSING'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE size      1='(1) < 1,000' 2='(2) 1,000 - 1,999' 3='(3) 2,000 - 2,999' 4='(4) 3,000 +'
                  6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE income    1='(1) NONE' 2='(2) UNDER $5,000' 3='(3) $5,000 - $6,300'
                  4='(4) $6,301 - $8,450' 5='(5) $8.451 - $10,600'
                  6='(6) $$10,601 - $12,700' 7='(7) $12,701 - $14,850'
                  8='(8) $14,851 - $17,000' 9='(9) $17,001 - $19,000'
                  10='(10) $19,001 - $21,300' 11='(11) $21,301 - $25,000'
                  12='(12) $25,001 - $30,000' 13='(13) $30,001 - $40,000'
                  14='(14) $40,001 - $50,000' 15='(15) $50,001 - $75,000'
                  16='(16) $75,001 +' 96='(96) NO SELF-ADMINISTERED QUEX' ;
  VALUE mulpregf  0='(0) NO REPORTED USE' 1='(1) USED 1 ILLICIT DRUG'
                  2='(2) USED 2 ILLICIT DRUGS' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE age2ffff  1='(1) <25 YEARS' 2='(2) 25 + YEARS' 6='(6) NO SELF-ADMINISTERED QUEX' ;
  VALUE incflag   0='(0) NOT IMPUTED' 1='(1) IMPUTED' 6='(6) NO SELF ADMINISTERED QUEX' ;
  VALUE int_flg   0='(0) No' 1='(1) Yes' ;
  VALUE int_stat  1='(1) Both IAQ and SAQ' 2='(2) Only IAQ' 3='(3) Neither IAQ or SAQ' ;
  VALUE saq_flg   0='(0) No' 1='(1) Yes' ;
  VALUE fileiaq   0='(0) NO' 1='(1) YES' ;
  VALUE filerpta  0='(0) NO' 1='(1) YES' ;
  VALUE filesaq   0='(0) NO' 1='(1) YES' ;
  VALUE filewta   0='(0) NO' 1='(1) YES' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=953;
INPUT
        CASEID 1-4              INT_TIME 5-8            IAQ_1 9-12
        IAQ_BOXA 13             IAQ_1A 14               IAQ_1B 15-16
        IAQ_4 17-18             IAQ_5 19-21             IAQ5FLAG 22
        IAQ_6 23-24             IAQ6FLAG 25             IAQ_DAY 26
        IAQ_7 27                IAQ_8 28-29             IAQ8FLAG 30
        IAQ_9 31-32             IAQ_10 33-34            IAQ_11 35-36
        IAQ_12A 37              IAQ_12B 38              IAQ_12C 39
        IAQ_12D 40              IAQ_12E 41              IAQ_12F 42
        IAQ_12G 43              IAQ_12H 44              IAQ_12HS 45-46
        IAQ_13A 47              IAQ_13B 48              IAQ_13C 49
        IAQ_13D 50              IAQ_13DS 51-52          IAQ_14 53
        IAQ_15 54-56            IAQ_16 57-59            IAQ_17FT 60-61
        IAQ_17IN 62-63          IAQ_18A 64              IAQ_18B 65
        IAQ_18C 66              IAQ_18D 67              IAQ_18DS 68-69
        IAQ_19A 70              IAQ_19B 71              IAQ_19C 72
        IAQ_20A 73              IAQ_21A 74              IAQ_20B 75
        IAQ_21B 76              IAQ_20C 77              IAQ_21C 78
        IAQ_20D 79              IAQ_21D 80              IAQ_20E 81
        IAQ_21E 82              IAQ_20F 83              IAQ_20SP 84-85
        IAQ_21F 86              IAQ_22 87               IAQ_22SP 88-89
        IAQ_23 90-91            IAQ_24A 92-93           IAQ_24B 94-95
        IAQ_BOXB 96             IAQ_24C 97-98           IAQ_24D 99-100
        IAQ_24E 101-102         IAQ_25 103              IAQ_26 104-105
        IAQ26FLG 106            IAQ_BOXC 107            IAQ_CNTR 108-109
        IAQ_WG 110-111          IQ27LB01 112-113        IQ27LB02 114-115
        IQ27LB03 116-117        IQ27LB04 118-119        IQ27LB05 120-121
        IQ27LB06 122-123        IQ27LB07 124-125        IQ27LB08 126-127
        IQ27LB09 128-129        IQ27LB10 130-131        IQ27OZ01 132-133
        IQ27OZ02 134-135        IQ27OZ03 136-137        IQ27OZ04 138-139
        IQ27OZ05 140-141        IQ27OZ06 142-143        IQ27OZ07 144-145
        IQ27OZ08 146-147        IQ27OZ09 148-149        IQ27OZ10 150-151
        IQ2801 152-153          IQ2802 154-155          IQ2803 156-157
        IQ2804 158-159          IQ2805 160-161          IQ2806 162-163
        IQ2807 164-165          IQ2808 166-167          IQ2809 168-169
        IQ2810 170-171          IQ2901 172              IQ2902 173
        IQ2903 174              IQ2904 175              IQ2905 176
        IQ2906 177              IQ2907 178              IQ2908 179
        IQ2909 180              IQ2910 181              IAQ_31 182-183
        IAQ_32 184              IAQ_33 185              IAQ_34 186
        IAQ_35 187-188          IAQ_36 189-190          IAQ_BOXD 191
        IAQ_37 192              IAQ_38 193-194          IAQ_39 195
        IAQ_40 196              IAQ_41 197-198          IAQ_42 199-200
        IAQ_43A 201             IAQ_43B 202             IAQ_43C 203
        IAQ_43D 204             IAQ_43E 205             IAQ_43F 206
        IAQ_43G 207             IAQ_43H 208             IAQ_43I 209
        IAQ_BOXE 210            IAQ_44 211              IAQ_45 212
        IAQ_BOXF 213            IAQ_46 214-215          IAQ_BOXG 216
        IAQ_47 217-218          IAQ_48 219              IAQ_49 220-222
        IAQ49FLG 223            IAQ_50A 224             IAQ_50AM 225
        IAQ_50B 226             IAQ_50BM 227            IAQ_50C 228
        IAQ_50CM 229            IAQ_50D 230             IAQ_50DM 231
        IAQ_50E 232             IAQ_50EM 233            IAQ_50F 234
        IAQ_50FM 235            IAQ_BOXH 236            IAQ_51A 237
        IAQ_51AM 238            IAQ_51B 239             IAQ_51BM 240
        IAQ_51C 241             IAQ_51CM 242            IAQ_51D 243
        IAQ_51DM 244            IAQ_51E 245             IAQ_51EM 246
        IAQ_51F 247             IAQ_51FM 248            SAQ_TIME 249-252
        LANG 253                IAQ_D2 254-255          AGECALC 256-257
        NEWLBS 258-259          NEWOZS 260-261          NEWGRAMS 262-265
        IAQ_EC 266-269          INFNUM 270              NEWLBS2 271-272
        NEWOZS2 273-274         NEWGRAM2 275-278        GHFLAG 279
        SAQ_1A 280              SAQ_1B 281              SAQ_1C 282-283
        SAQ_1D 284-285          SAQ_2A 286              SAQ_2B 287
        SAQ_2C 288-289          SAQ_2D 290-291          SAQ_3A 292
        SAQ_3B 293              SAQ_3C 294-295          SAQ_3D 296-297
        SAQ_4A 298              SAQ_4B 299              SAQ_4C 300-301
        SAQ_4D 302-303          SAQ_5A 304              SAQ_5B 305
        SAQ_5C 306-307          SAQ_5D 308-309          SAQ_6A 310
        SAQ_6B 311              SAQ_6C 312-313          SAQ_6D 314-315
        SAQ_7A 316              SAQ_7B 317              SAQ_7C 318-319
        SAQ_7D 320-321          SAQ_8A 322              SAQ_8B 323
        SAQ_8C 324-325          SAQ_8D 326-327          SAQ_9A 328
        SAQ_9B 329              SAQ_9C 330-331          SAQ_9D 332-333
        SAQ_10A 334             SAQ_10B 335             SAQ_10C 336-337
        SAQ_10D 338-339         SAQ_11A 340             SAQ_11B 341
        SAQ_11C 342-343         SAQ_11D 344-345         SAQ_12A 346
        SAQ_12B 347             SAQ_12C 348-349         SAQ_12D 350-351
        SAQ_13A 352             SAQ_13B 353             SAQ_13C 354-355
        SAQ_13D 356-357         SAQ_14A 358             SAQ_14B 359
        SAQ_14C 360-361         SAQ_14D 362-363         SAQ_15A 364
        SAQ_15B 365             SAQ_15C 366-367         SAQ_15D 368-369
        SAQ_16A 370             SAQ_16B 371             SAQ_16C 372-373
        SAQ_16D 374-375         SAQ_17A 376             SAQ_17B 377
        SAQ_17C 378-379         SAQ_17D 380-381         SAQ_18A 382
        SAQ_18B 383             SAQ_18C 384-385         SAQ_18D 386-387
        SAQ_19A 388             SAQ_19B 389             SAQ_19C 390-391
        SAQ_19D 392-393         SAQ_20A 394             SAQ_20B 395
        SAQ_20C 396-397         SAQ_20D 398-399         SAQ_21A 400
        SAQ_21B 401             SAQ_21C 402-403         SAQ_21D 404-405
        SAQ_22A 406             SAQ_22B 407             SAQ_22C 408-409
        SAQ_22D 410-411         SAQ_23A 412             SAQ_23B 413
        SAQ_23C 414-415         SAQ_23D 416-417         SAQ_24A 418
        SAQ_24B 419             SAQ_24C 420-421         SAQ_24D 422-423
        SAQ_25A 424             SAQ_25B 425             SAQ_25C 426-427
        SAQ_25D 428-429         SAQ_26A 430             SAQ_26B 431
        SAQ_26C 432-433         SAQ_26D 434-435         SAQ_27A 436
        SAQ_27B 437             SAQ_27C 438-439         SAQ_27D 440-441
        SAQ_28A 442             SAQ_28B 443             SAQ_28C 444-445
        SAQ_28D 446-447         SAQ_29A 448             SAQ_29B 449
        SAQ_29C 450-451         SAQ_29D 452-453         SAQ_30A 454
        SAQ_30B 455             SAQ_30C 456-457         SAQ_30D 458-459
        SAQ_31A 460             SAQ_31B 461             SAQ_31C 462-463
        SAQ_31D 464-465         SAQ_32A 466             SAQ_32B 467
        SAQ_32C 468-469         SAQ_32D 470-471         SAQ_33A 472
        SAQ_33B 473             SAQ_33C 474             SAQ_33D 475-476
        SAQ_33E 477-478         SAQ_34A 479             SAQ_34B 480
        SAQ_34C 481             SAQ_34D 482-483         SAQ_34E 484-485
        SAQ_35A 486             SAQ_35B 487             SAQ_35C 488
        SAQ_35D 489-490         SAQ_35E 491-492         SAQ_36A 493
        SAQ_36B 494             SAQ_36C 495             SAQ_36D 496-497
        SAQ_36E 498-499         SAQ_37H 500             SAQ_37I 501
        SAQ_38 502              SAQ_39 503              SAQ_43A 504
        SAQ_43B 505             SAQ_43C 506             SAQ_43D 507
        SAQ_43E 508             SAQ_43F 509             SAQ_43G 510
        SAQ_43H 511             SAQ_43I 512             SAQ_43J 513
        SAQ_43K 514             SAQ_43L 515             SAQ_44 516
        SAQ_45 517-518          SAQ_46 519              SAQ_47 520-521
        SAQ_48 522              FLAG44 523              FLAG46 524
        FLAG48 525              F_AGEGR2 526            F_RACETH 527
        IAGEGRP2 528            PMOTHR 529-534 .4       STRATUM 535
        PHOSP 536-541 .4        DAYFCTR 542-547 .4      P 548-553 .4
        STATUS 554              AELGFCTR 555            I_RACETH 556
        NUMBABES 557            NRFCTR 558              NRWGT 559-567 .4
        TRMADJMW 568-577 .4     FMOTHWGT 578-587 .4     TRMFCTR 588-593 .4
        ACTDAYS 594-595         BWGT 596-604 .4         FACTOR 605-610 .4
        FWGT 611-620 .4         RESP 621                ALC3TUP 622
        ANY3TUP 623             CIG3TUP 624             COK3TUP 625
        COKA3TUP 626            CRK3TUP 627             DONE3TUP 628
        HER3TUP 629             METH3TUP 630            THC3TUP 631
        INCOME3 632             GAGEFLAG 633            GAGE 634-635
        CIGPREG 636             ALCPREG 637             THCPREG 638
        CRKPREG 639             COKPREG 640             HERPREG 641
        DONEPREG 642            METHPREG 643            ALLPREG 644
        CIGEVER 645             THCEVER 646             COKEVER 647
        RACETFLG 648            PAYFLAG 649             VSTSFLAG 650
        METRO 651               EDUCFLAG 652            EMPLFLAG 653
        RACEUP 654              AGE5 655                AGE3 656
        PAYUP 657               MARITAL1 658            MARITAL2 659
        EDUC 660                EDUC2 661               EMPL1 662
        EMPL2 663               COKAPREG 664            HALPREG 665
        INHPREG 666             ILSEDA 667              ILTRANQ 668
        ILAMPHET 669            ILANAL 670              ILPSY 671
        SEDA 672                TRANQ 673               AMPHET 674
        ANAL 675                SCRPSY 676              CIGYR 677
        ALCYR 678               THCYR 679               CRKYR 680
        COKYR 681               HERYR 682               DONEYR 683
        METHYR 684              COKAYR 685              ALLYR 686
        ALCIG 687               ANY3M 688               THC3M 689
        CRK3M 690               COK3M 691               COKA3M 692
        HER3M 693               DONE3M 694              METH3M 695
        ALC3M 696               CIG3M 697               ANY1T 698
        THC1T 699               CRK1T 700               COK1T 701
        COKA1T 702              HER1T 703               DONE1T 704
        METH1T 705              ALC1T 706               CIG1T 707
        ANY2T 708               THC2T 709               CRK2T 710
        COK2T 711               COKA2T 712              HER2T 713
        DONE2T 714              METH2T 715              ALC2T 716
        CIG2T 717               ANY3D 718               THC3D 719
        CRK3D 720               COK3D 721               COKA3D 722
        HER3D 723               DONE3D 724              METH3D 725
        ALC3D 726               CIG3D 727               CIG1TS 728
        CIG3TC 729              ALC1TS 730              ALC3TC 731
        NEWVOL 732-734          COKES 735               COKEQ 736
        COKEN 737-741           AMPHS 742               AMPHQ 743
        AMPHN 744               METHQ 745               METHN 746-749
        THCS 750                THCQ 751                THCN 752-754
        OPS 755                 CODQ 756                CODN 757-760
        MORPHQ 761              MORPHN 762-765          AMPHET3D 766
        ANAL3D 767              AMETH3D 768             HANAL3D 769
        THCTEST 770             COKETEST 771            AMPHTEST 772
        OPTEST 773              ANYTEST 774             THCRT 775
        COKERT 776              SIZE 777                TADJ1 778-786 .4
        TADJ2 787-795 .4        TADJ3 796-804 .4        TADJ4 805-813 .4
        TADJ5 814-822 .4        TADJ6 823-831 .4        TADJ7 832-840 .4
        TADJ8 841-849 .4        TADJ9 850-858 .4        TADJ10 859-867 .4
        TADJ11 868-876 .4       TADJ12 877-885 .4       TADJ13 886-894 .4
        TADJ14 895-903 .4       TADJ15 904-913 .4       TADJ16 914-922 .4
        TADJ17 923-931 .4       TADJ18 932-940 .4       INCOME 941-942
        MULPREG2 943            AGE2 944                INCFLAG 945
        PSU_VAR 946             INT_FLG 947             INT_STAT 948
        SAQ_FLG 949             FILEIAQ 950             FILERPTA 951
        FILESAQ 952             FILEWTA 953             ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   INT_TIME= 'TIME TO COMPLETE IAQ (MINS)'
   IAQ_1   = 'DEL DATE-DATE DR SAID BABY DUE (DAYS)'
   IAQ_BOXA= 'BOX A (DATE GIVEN IN QUES. 1?)'
   IAQ_1A  = 'DR SAY BABY ON TIME AT DELIVERY'
   IAQ_1B  = 'HOW MANY WEEKS (LATE/EARLY)?'
   IAQ_4   = 'NUM WKS PREGNANT WHEN BABY BORN'
   IAQ_5   = 'DELIV DATE-DATE LAST PERIOD (WKS)'
   IAQ5FLAG= 'IMPUTE FLAG FOR IAQ_5'
   IAQ_6   = 'DEL DATE-DATE LEARN PREG (WKS)'
   IAQ6FLAG= 'IMPUTE FLAG FOR IAQ_6'
   IAQ_DAY = 'DAY ABOUT BEG MIDDLE END OF MONTH'
   IAQ_7   = 'GET ANY PRENATAL CARE THIS PREG'
   IAQ_8   = 'DEL DATE - DATE 1ST PRE-NATAL (WKS)'
   IAQ8FLAG= 'IMPUTE FLAG FOR IAQ_8'
   IAQ_9   = 'NUM WKS PREG AT FIRST VISIT'
   IAQ_10  = 'APPROX NUM PRENATAL VISITS'
   IAQ_11  = 'TYPE OF FACILITY USED FOR CARE'
   IAQ_12A = 'RECEIVED PREG TEST'
   IAQ_12B = 'RECEIVED CHECKUPS'
   IAQ_12C = 'RECEIVED LAB TESTING'
   IAQ_12D = 'HAD SONOGRAM OR ULTRASOUND'
   IAQ_12E = 'HAD AN X-RAY'
   IAQ_12F = 'HAD AMNIOCENTESIS OR CVS'
   IAQ_12G = 'HAD EMERGENCY VISITS'
   IAQ_12H = 'HAD OTHER SERVICES'
   IAQ_12HS= 'OTHER SERVICE SPECIFIED'
   IAQ_13A = 'PROBLEMS WITH MONEY OR INSURANCE?'
   IAQ_13B = 'PROBLEMS WITH APPOINTMENTS, WORK OR'
   IAQ_13C = 'PROBLEMS WITH HEALTH CARE PROVIDERS'
   IAQ_13D = 'ANY OTHER PROBLEMS SUCH AS DID NOT'
   IAQ_13DS= 'OTHER PROBLEM SPECIFIED'
   IAQ_14  = 'RECEIVE W.I.C. FOOD FOR SELF'
   IAQ_15  = 'WEIGHT JUST BEFORE BECAME PREG (LBS)'
   IAQ_16  = 'WEIGHT JUST BEFORE DELIVERY (LBS)'
   IAQ_17FT= 'YOUR HEIGHT, FEET'
   IAQ_17IN= 'YOUR HEIGHT, INCHES'
   IAQ_18A = 'HAD DIABETES BEFORE PREG'
   IAQ_18B = 'HAD HIGH BLOOD PRESSURE BEFORE'
   IAQ_18C = 'HAD SEIZURE DISORDER BEFORE PREG'
   IAQ_18D = 'HAD OTHER CHRONIC COND BEFORE'
   IAQ_18DS= 'SPECIFY OTHER CHRONIC CONDITIONS'
   IAQ_19A = 'DEVELOP ANEMIA DURING PREG'
   IAQ_19B = 'DEVELOP HIGH BLOOD PRESS DURING'
   IAQ_19C = 'DEVELOP DIABETES DURING PREG'
   IAQ_20A = 'HAVE URINARY TRACT INFECTION DURING'
   IAQ_21A = 'TAKE ANTIBIOTICS FOR UTI'
   IAQ_20B = 'HAVE CHLAMYDIA DURING PREG'
   IAQ_21B = 'TAKE ANTIBIOTICS FOR CHLAMYDIA'
   IAQ_20C = 'HAVE SYPHILIS DURING PREGNANCY'
   IAQ_21C = 'TAKE ANTIBIOTICS FOR SYPHILIS'
   IAQ_20D = 'HAVE GONORRHEA DURING PREGNANCY'
   IAQ_21D = 'TAKE ANTIBIOTICS FOR GONORRHEA'
   IAQ_20E = 'HAVE GENITAL HERPES DURING PREG'
   IAQ_21E = 'TAKE ANTIBIOTICS, GENITAL HERPES'
   IAQ_20F = 'HAVE ANY OTHER STD'
   IAQ_20SP= 'OTHER STD SPECIFIED'
   IAQ_21F = 'TAKE ANTIBIOTICS FOR THIS STD'
   IAQ_22  = 'TAKE ANTIBIOTICS FOR OTHER REASON'
   IAQ_22SP= 'SPECIFY REASON TAKE ANTIBIOTICS'
   IAQ_23  = 'NUM PREVIOUS PREGNANCIES'
   IAQ_24A = 'NUM OF LIVE BIRTH OUTCOMES'
   IAQ_24B = 'NUM OF MISCARRIAGES'
   IAQ_BOXB= 'TOTAL = LIVE BIRTHS PLUS MISC'
   IAQ_24C = 'NUM OF STILLBIRTHS'
   IAQ_24D = 'NUM OF ECTOPIC PREGNANCIES'
   IAQ_24E = 'NUM OF INDUCED ABORTIONS'
   IAQ_25  = 'OUTCOME OF LAST PREGNANCY'
   IAQ_26  = 'SUBJECT''S AGE AT LAST PREGNANCY'
   IAQ26FLG= 'IMPUTE FLAG FOR IAQ_26'
   IAQ_BOXC= 'BOX C ANY PREVIOUS LIVE BIRTHS'
   IAQ_CNTR= 'NUM OF LIVE BORN BABIES'
   IAQ_WG  = '# WEEKS GESTATION'
   IQ27LB01= 'PREV BABY 01 WEIGHT, POUNDS'
   IQ27LB02= 'PREV BABY 02 WEIGHT, POUNDS'
   IQ27LB03= 'PREV BABY 03 WEIGHT, POUNDS'
   IQ27LB04= 'PREV BABY 04 WEIGHT, POUNDS'
   IQ27LB05= 'PREV BABY 05 WEIGHT, POUNDS'
   IQ27LB06= 'PREV BABY 06 WEIGHT, POUNDS'
   IQ27LB07= 'PREV BABY 07 WEIGHT, POUNDS'
   IQ27LB08= 'PREV BABY 08 WEIGHT, POUNDS'
   IQ27LB09= 'PREV BABY 09 WEIGHT, POUNDS'
   IQ27LB10= 'PREV BABY 10 WEIGHT, POUNDS'
   IQ27OZ01= 'PREV BABY 01 WEIGHT, OUNCES'
   IQ27OZ02= 'PREV BABY 02 WEIGHT, OUNCES'
   IQ27OZ03= 'PREV BABY 03 WEIGHT, OUNCES'
   IQ27OZ04= 'PREV BABY 04 WEIGHT, OUNCES'
   IQ27OZ05= 'PREV BABY 05 WEIGHT, OUNCES'
   IQ27OZ06= 'PREV BABY 06 WEIGHT, OUNCES'
   IQ27OZ07= 'PREV BABY 07 WEIGHT, OUNCES'
   IQ27OZ08= 'PREV BABY 08 WEIGHT, OUNCES'
   IQ27OZ09= 'PREV BABY 09 WEIGHT, OUNCES'
   IQ27OZ10= 'PREV BABY 10 WEIGHT, OUNCES'
   IQ2801  = 'AGE AT BIRTH OF FIRST BABY'
   IQ2802  = 'AGE AT BIRTH OF 2ND   BABY'
   IQ2803  = 'AGE AT BIRTH OF 3RD   BABY'
   IQ2804  = 'AGE AT BIRTH OF 4TH   BABY'
   IQ2805  = 'AGE AT BIRTH OF 5TH   BABY'
   IQ2806  = 'AGE AT BIRTH OF 6TH   BABY'
   IQ2807  = 'AGE AT BIRTH OF 7TH   BABY'
   IQ2808  = 'AGE AT BIRTH OF 8TH   BABY'
   IQ2809  = 'AGE AT BIRTH OF 9TH   BABY'
   IQ2810  = 'AGE AT BIRTH OF 10TH  BABY'
   IQ2901  = 'BABY 01 MORE THAN 2 WKS EARLY'
   IQ2902  = 'BABY 02 MORE THAN 2 WKS EARLY'
   IQ2903  = 'BABY 03 MORE THAN 2 WKS EARLY'
   IQ2904  = 'BABY 04 MORE THAN 2 WKS EARLY'
   IQ2905  = 'BABY 05 MORE THAN 2 WKS EARLY'
   IQ2906  = 'BABY 06 MORE THAN 2 WKS EARLY'
   IQ2907  = 'BABY 07 MORE THAN 2 WKS EARLY'
   IQ2908  = 'BABY 08 MORE THAN 2 WKS EARLY'
   IQ2909  = 'BABY 09 MORE THAN 2 WKS EARLY'
   IQ2910  = 'BABY 10 MORE THAN 2 WKS EARLY'
   IAQ_31  = 'CURRENT MARITAL STATUS'
   IAQ_32  = 'ARE YOU HISPANIC OR OF SPANISH'
   IAQ_33  = 'HISPANIC GROUP BEST DESCRIBES YOU'
   IAQ_34  = 'RACIAL BACKGROUND GROUP'
   IAQ_35  = 'LAST GRADE IN SCHOOL COMPLETED'
   IAQ_36  = 'NUM YEARS VOCATIONAL SCHOOL'
   IAQ_BOXD= 'BOX D FINISHED GRADE 12'
   IAQ_37  = 'HAVE A GED'
   IAQ_38  = 'DOING MOST MONTH BEFORE PREG'
   IAQ_39  = 'WORKING PART-TIME OR FULL-TIME'
   IAQ_40  = 'WERE YOU LOOKING FOR WORK?'
   IAQ_41  = 'TOTAL NUM IN HOUSEHOLD'
   IAQ_42  = 'NUM PEOPLE RELATED BY BIRTH/MARRIAGE'
   IAQ_43A = 'INCOME FROM WAGES AND SALARIES'
   IAQ_43B = 'INCOME FROM PUBLIC ASSISTANCE'
   IAQ_43C = 'INCOME FROM FOOD STAMPS'
   IAQ_43D = 'INCOME FROM HOUSING ASSISTANCE'
   IAQ_43E = 'INCOME FROM SOCIAL SECURITY OR SSI'
   IAQ_43F = 'INCOME FROM UNEMPLOYMENT INS'
   IAQ_43G = 'INCOME FROM VETERAN PAYMENT'
   IAQ_43H = 'INCOME FROM CHILD SUPPORT/ALIMONY'
   IAQ_43I = 'INCOME FROM OTHER SOURCES'
   IAQ_BOXE= 'BOX E SUBJECT LIVED ALONE'
   IAQ_44  = 'AFDC FOR SUBJECT'
   IAQ_45  = 'SOCIAL SECURITY FOR SUBJECT'
   IAQ_BOXF= 'BOX F LIVED ONLY WITH NON-FAMILY'
   IAQ_46  = 'TOTAL FAMILY INCOME'
   IAQ_BOXG= 'BOX G ONLY FAM MEMBERS IN HOUSE'
   IAQ_47  = 'TOTAL HOUSEHOLD INCOME'
   IAQ_48  = 'DO YOU HAVE A MEDICAID CARD?'
   IAQ_49  = 'WEEKS BETW RECPT OF MEDICAID CARD, BIRTH'
   IAQ49FLG= 'IMPUTE FLAG FOR IAQ_49'
   IAQ_50A = 'HOSP BILL PAID OWN INCOME'
   IAQ_50AM= 'OWN INCOME MAIN SOURCE'
   IAQ_50B = 'HOSP BILL PAID PARENTS, RELATIVES'
   IAQ_50BM= 'PARENTS MAIN SOURCE PAY'
   IAQ_50C = 'HOSP BILL PAID INSURANCE'
   IAQ_50CM= 'INSURANCE MAIN SOURCE PAY'
   IAQ_50D = 'HOSP BILL PAID BY MEDICAID'
   IAQ_50DM= 'MEDICAID MAIN SOURCE PAY'
   IAQ_50E = 'HOSP BILL PAID OTHER GOVT AID'
   IAQ_50EM= 'OTHER GOVT AID MAIN SOURCE'
   IAQ_50F = 'HOSP BILL PAID OTHER SOURCE'
   IAQ_50FM= 'OTHER SOURCE MAIN PAYER'
   IAQ_BOXH= 'BOX H SUBJECT RECD PRENATAL CARE'
   IAQ_51A = 'PRENATAL CARE SELF PAY'
   IAQ_51AM= 'SELF PAY MAIN PAYMENT FOR PREN CARE'
   IAQ_51B = 'PRENATAL CARE PARENTS PAY'
   IAQ_51BM= 'PARENTS MAIN SOURCE CARE PAY'
   IAQ_51C = 'PRENATAL CARE INSURANCE PAY'
   IAQ_51CM= 'INSURANCE MAIN SOURCE PAY'
   IAQ_51D = 'PRENATAL CARE MEDICAID PAY'
   IAQ_51DM= 'MEDICAID MAIN SOURCE PAY'
   IAQ_51E = 'PRENATAL CARE OTHER GOVT ASST PAY'
   IAQ_51EM= 'OTHER GOVT ASST MAIN SOURCE PAY'
   IAQ_51F = 'PRENATAL CARE OTHER PAYER'
   IAQ_51FM= 'OTHER SOURCE MAIN PAYER'
   SAQ_TIME= 'TIME IN MINS TO COMPLETE SAQ'
   LANG    = 'INTERVIEW IN ENGLISH OR SPANISH'
   IAQ_D2  = 'DEL DATE - DATE OF LAST PERIOD (WKS)'
   AGECALC = 'SUBJECTS AGE AT DELIVERY DATE'
   NEWLBS  = 'LB WT SINGLE BABY/1ST OF MULT BIRTH'
   NEWOZS  = 'OZ WT SINGLE BABY/1ST OF MULT BIRTH'
   NEWGRAMS= 'GRAM WT SINGLE BABY/1ST OF MULT BIRTH'
   IAQ_EC  = 'DEL DATE-EST DATE OF CONFINEMENT (WKS)'
   INFNUM  = 'NUM INFANTS FOR WHOM WEIGHT GIVEN'
   NEWLBS2 = 'LB WT 2ND OF MULT BIRTH'
   NEWOZS2 = 'OZ WT 2ND OF MULT BIRTH'
   NEWGRAM2= 'GRAM WT 2ND OF MULT BIRTH'
   GHFLAG  = 'COMPUTED NUMBER OF WEEKS GESTATION'
   SAQ_1A  = 'QTR 1; SMOKE CIGARETTES'
   SAQ_1B  = 'QTR 1; DA/WK USUALLY SMOKE'
   SAQ_1C  = 'QTR 1; USUAL NUM SMOKE'
   SAQ_1D  = 'QTR 1; MOST NUM SMOKED'
   SAQ_2A  = 'QTR 1; DRINK ALCOHOLIC BEVERAGES'
   SAQ_2B  = 'QTR 1; DA/WK USUALLY DRINK'
   SAQ_2C  = 'QTR 1; USUAL NUM DRINKS PER DAY'
   SAQ_2D  = 'QTR 1; MOST NUM DRINKS PER DAY'
   SAQ_3A  = 'QTR 1; USE MARIJUANA'
   SAQ_3B  = 'QTR 1; DA/WK USUALLY USE MARIJUANA'
   SAQ_3C  = 'QTR 1; USUAL TIMES/DAY USE MARIJUANA'
   SAQ_3D  = 'QTR 1; MOST TIMES/DAY USED MARIJUANA'
   SAQ_4A  = 'QTR 1; USE CRACK'
   SAQ_4B  = 'QTR 1; DA/WK USUALLY USE CRACK'
   SAQ_4C  = 'QTR 1; TIMES/DA USUALLY USE CRACK'
   SAQ_4D  = 'QTR 1; MOST TIMES/DAY USED CRACK'
   SAQ_5A  = 'QTR 1; USE OTHER COCAINE'
   SAQ_5B  = 'QTR 1; DA/WK USE OTHER COCAINE'
   SAQ_5C  = 'QTR 1; TIMES/DA USUAL USE OTHER COCAINE'
   SAQ_5D  = 'QTR 1; MOST TIMES/DAY USE OTHER COCAINE'
   SAQ_6A  = 'QTR 1; USE HEROIN'
   SAQ_6B  = 'QTR 1; DA/WK USE HEROIN'
   SAQ_6C  = 'QTR 1; TIMES/DAY USUALLY USE HEROIN'
   SAQ_6D  = 'QTR 1; MOST TIMES/DAY USE HEROIN'
   SAQ_7A  = 'QTR 1; USE METHADONE'
   SAQ_7B  = 'QTR 1; DA/WK USE METHADONE'
   SAQ_7C  = 'QTR 1; TIMES/DAY USUALLY USE METHADONE'
   SAQ_7D  = 'QTR 1; MOST TIMES/DAY USE METHADONE'
   SAQ_8A  = 'QTR 1; USE METHAMPHETAMINE'
   SAQ_8B  = 'QTR 1; DA/WK USE METHAMPHETAMINE'
   SAQ_8C  = 'QTR 1; TIME/DA USUAL USE METHAMPHETAMINE'
   SAQ_8D  = 'QTR 1; MOST TIME/DAY USE METHAMPHETAMINE'
   SAQ_9A  = 'QTR 2; SMOKE CIGARETTES'
   SAQ_9B  = 'QTR 2; DA/WK USUALLY SMOKE'
   SAQ_9C  = 'QTR 2; USUAL NUM PER DAY SMOKE'
   SAQ_9D  = 'QTR 2; MOST NUM PER DAY SMOKED'
   SAQ_10A = 'QTR 2; DRINK ALCOHOLIC BEVERAGES'
   SAQ_10B = 'QTR 2; DA/WK USUALLY DRINK'
   SAQ_10C = 'QTR 2; USUAL NUM DRINKS PER DAY'
   SAQ_10D = 'QTR 2; MOST NUM DRINKS PER DAY'
   SAQ_11A = 'QTR 2; USE MARIJUANA'
   SAQ_11B = 'QTR 2; DA/WK USE MARIJUANA'
   SAQ_11C = 'QTR 2; USUAL TIMES/DAY USE MARIJUANA'
   SAQ_11D = 'QTR 2; MOST TIMES/DAY USE MARIJUANA'
   SAQ_12A = 'QTR 2; USE CRACK'
   SAQ_12B = 'QTR 2; DA/WK USE CRACK'
   SAQ_12C = 'QTR 2; TIMES/DAY USUALLY USE CRACK'
   SAQ_12D = 'QTR 2; MOST TIMES/DAY USE CRACK'
   SAQ_13A = 'QTR 2; USE OTHER COCAINE'
   SAQ_13B = 'QTR 2; DA/WK USE OTHER COCAINE'
   SAQ_13C = 'QTR 2; USUAL TIME/DA USE OTHER COCAINE'
   SAQ_13D = 'QTR 2; MOST TIME/DA USE OTHER COCAINE'
   SAQ_14A = 'QTR 2; USE HEROIN'
   SAQ_14B = 'QTR 2; DA/WK USE HEROIN'
   SAQ_14C = 'QTR 2; TIMES/DAY USUALLY USE HEROIN'
   SAQ_14D = 'QTR 2; MOST TIMES/DAY USE HEROIN'
   SAQ_15A = 'QTR 2; USE METHADONE'
   SAQ_15B = 'QTR 2; DA/WK USE METHADONE'
   SAQ_15C = 'QTR 2; USUAL TIMES/DAY USE METHADONE'
   SAQ_15D = 'QTR 2; MOST TIMS/DAY USE METHADONE'
   SAQ_16A = 'QTR 2; USE METHAMPHETAMINE'
   SAQ_16B = 'QTR 2; DA/WK USE METHAMPHETAMINE'
   SAQ_16C = 'QTR 2; USUAL TIME/DA USE METHAMPHETAMINE'
   SAQ_16D = 'QTR 2; MOST TIME/DA USE METHAMPHETAMINE'
   SAQ_17A = 'QTR 3; SMOKE CIGARETTES'
   SAQ_17B = 'QTR 3; DA/WK USUALLY SMOKE'
   SAQ_17C = 'QTR 3; NUM USUALLY SMOKE PER DAY'
   SAQ_17D = 'QTR 3; NUM MOST SMOKE PER DAY'
   SAQ_18A = 'QTR 3; DRINK ALCOHOLIC BEVERAGES'
   SAQ_18B = 'QTR 3; DA/WK USUALLY DRINK'
   SAQ_18C = 'QTR 3; NUM USUALLY DRINK PER DAY'
   SAQ_18D = 'QTR 3; MOST NUM DRINKS PER DAY'
   SAQ_19A = 'QTR 3; USE MARIJUANA'
   SAQ_19B = 'QTR 3; DA/WK USE MARIJUANA'
   SAQ_19C = 'QTR 3; TIMES/DAY USUALLY USE MARIJUANA'
   SAQ_19D = 'QTR 3; MOST TIMES/DAY USE MARIJUANA'
   SAQ_20A = 'QTR 3; USE CRACK'
   SAQ_20B = 'QTR 3; DA/WK USE CRACK'
   SAQ_20C = 'QTR 3; TIMES/DAY USUALLY USE CRACK'
   SAQ_20D = 'QTR 3; MOST TIMES/DAY USE CRACK'
   SAQ_21A = 'QTR 3; USE OTHER COCAINE'
   SAQ_21B = 'QTR 3; DA/WK USE OTHER COCAINE'
   SAQ_21C = 'QTR 3; TIME/DA USUAL USE OTHER COCAINE'
   SAQ_21D = 'QTR 3; MOST TIME/DA USE OTHER COCAINE'
   SAQ_22A = 'QTR 3; USE HEROIN'
   SAQ_22B = 'QTR 3; DA/WK USE HEROIN'
   SAQ_22C = 'QTR 3; TIMES/DAY USUALLY USE HEROIN'
   SAQ_22D = 'QTR 3; MOST TIMES/DAY USE HEROIN'
   SAQ_23A = 'QTR 3; USE METHADONE'
   SAQ_23B = 'QTR 3; DA/WK USE METHADONE'
   SAQ_23C = 'QTR 3; TIMES/DAY USUAL USE METHADONE'
   SAQ_23D = 'QTR 3; MOST TIMES/DAY USE METHADONE'
   SAQ_24A = 'QTR 3; USE METHAMPHETAMINE'
   SAQ_24B = 'QTR 3; DA/WK USE METHAMPHETAMINE'
   SAQ_24C = 'QTR 3; TIME/DA USUAL USE METHAMPHETAMINE'
   SAQ_24D = 'QTR 3; MOST TIME DA USE METHAMPHETAMINE'
   SAQ_25A = 'QTR 4; SMOKE CIGARETTES'
   SAQ_25B = 'QTR 4; DA/WK SMOKE CIGARETTES'
   SAQ_25C = 'QTR 4; NUM USUALLY SMOKE PER DAY'
   SAQ_25D = 'QTR 4; MOST NUM SMOKED PER DAY'
   SAQ_26A = 'QTR 4; DRINK ALCOHOLIC BEVERAGES'
   SAQ_26B = 'QTR 4; DA/WK USUALLY DRINK'
   SAQ_26C = 'QTR 4; NUM USUALLY DRINK PER DAY'
   SAQ_26D = 'QTR 4; MOST NUM DRINKS PER DAY'
   SAQ_27A = 'QTR 4; USE MARIJUANA'
   SAQ_27B = 'QTR 4; DA/WK USE MARIJUANA'
   SAQ_27C = 'QTR 4; TIMES/DAY USUALLY USE MARIJUANA'
   SAQ_27D = 'QTR 4; MOST TIMES/DAY USE MARIJUANA'
   SAQ_28A = 'QTR 4; USE CRACK'
   SAQ_28B = 'QTR 4; DA/WK USE CRACK'
   SAQ_28C = 'QTR 4; USUAL TIMES/DAY USE CRACK'
   SAQ_28D = 'QTR 4; MOST TIMES/DAY USE CRACK'
   SAQ_29A = 'QTR 4; USE OTHER COCAINE'
   SAQ_29B = 'QTR 4; DA/WK USE OTHER COCAINE'
   SAQ_29C = 'QTR 4; TIMES/DAY USUAL USE OTHER COCAINE'
   SAQ_29D = 'QTR 4; MOST TIMES/DAY USE OTHER COCAINE'
   SAQ_30A = 'QTR 4; USE HEROIN'
   SAQ_30B = 'QTR 4; DA/WK USE HEROIN'
   SAQ_30C = 'QTR 4; TIMES/DAY USUAL USE HEROIN'
   SAQ_30D = 'QTR 4; MOST TIMES/DAY USE HEROIN'
   SAQ_31A = 'QTR 4; USE METHADONE'
   SAQ_31B = 'QTR 4; DA/WK USE METHADONE'
   SAQ_31C = 'QTR 4; TIMES/DAY USUAL USE METHADONE'
   SAQ_31D = 'QTR 4; MOST TIMES/DAY USE METHADONE'
   SAQ_32A = 'QTR 4; USE METHAMPHETAMINE'
   SAQ_32B = 'QTR 4; DA/WK USE METHAMPHETAMINE'
   SAQ_32C = 'QTR 4; TIME/DA USUAL USE METHAMPHETAMINE'
   SAQ_32D = 'QTR 4; MOST TIME/DA USE METHAMPHETAMINE'
   SAQ_33A = 'RX SEDATIVE; USE AS DR ORDER'
   SAQ_33B = 'RX SEDATIVE; USE NOT AS DR ORDER'
   SAQ_33C = 'RX SEDATIVE;DA/WK USE NOT AS ORD'
   SAQ_33D = 'RX SEDATIVE; USUAL NUM/DA NOT PRES USE'
   SAQ_33E = 'RX SEDATIVE; MOST NUM/DA NOT PRES USE'
   SAQ_34A = 'RX TRANQUILIZER; USE AS DR ORDER'
   SAQ_34B = 'RX TRANQUILIZER;USE NOT AS ORDER'
   SAQ_34C = 'RX TRANQUILIZER;DA/WK NOT AS ORD'
   SAQ_34D = 'RX TRANQUIL; USUAL NUM/DA NOT PRES USE'
   SAQ_34E = 'RX TRANQUIL; MOST NUM/DA NOT PRES USE'
   SAQ_35A = 'RX AMPHETAMINES; USE AS DR ORDER'
   SAQ_35B = 'RX AMPHETAMINE;USE NOT AS DR ORD'
   SAQ_35C = 'RX AMPHET; DA/WK USE NOT AS PRES'
   SAQ_35D = 'RX AMPHET; USUAL NUM/DA NOT PRES USE'
   SAQ_35E = 'RX AMPHET; MOST NUM/DA NOT PRES USE'
   SAQ_36A = 'RX ANALGESICS; USE AS DR ORDER'
   SAQ_36B = 'RX ANALGESICS; USE NOT AS DR ORDER'
   SAQ_36C = 'RX ANALGESIC;DA/WK NOT PRES USE'
   SAQ_36D = 'RX ANALGESIC; USUAL NUM/DA NOT PRES USE'
   SAQ_36E = 'RX ANALGESIC; MOST NUM/DA NOT PRES USE'
   SAQ_37H = 'MISC DRUG; USE HALLUCINOGENS'
   SAQ_37I = 'MISC DRUG; USE INHALANTS'
   SAQ_38  = 'MISC DRUG; LIVE WITH SMOKER'
   SAQ_39  = 'MISC DRUG; GET HELP STOP SMOKING'
   SAQ_43A = 'LAST 3 DA; SMOKE CIGARETTES'
   SAQ_43B = 'LAST 3 DA; DRINK ALCOHOL'
   SAQ_43C = 'LAST 3 DA; USE MARIJUANA'
   SAQ_43D = 'LAST 3 DA; USE CRACK'
   SAQ_43E = 'LAST 3 DA; USE OTHER COCAINE'
   SAQ_43F = 'LAST 3 DA; USE HEROIN'
   SAQ_43G = 'LAST 3 DA; USE METHADONE'
   SAQ_43H = 'LAST 3 DA; USE METHAMPHETAMINE'
   SAQ_43I = 'LAST 3 DA; USE AMPHETAMINES'
   SAQ_43J = 'LAST 3 DA; USE TRANQUILIZERS'
   SAQ_43K = 'LAST 3 DA; USE SEDATIVES'
   SAQ_43L = 'LAST 3 DA; USE ANALGESICS'
   SAQ_44  = 'MOST RECENT TIME SMOKED CIGARETTE'
   SAQ_45  = 'AGE AT FIRST USE MARIJUANA'
   SAQ_46  = 'MOST RECENT USE OF MARIJUANA'
   SAQ_47  = 'AGE FIRST TRY COCAINE'
   SAQ_48  = 'MOST RECENT USE OF COCAINE'
   FLAG44  = 'SMOKING DATA INCONSISTENT'
   FLAG46  = 'MARIJUANA USE DATA INCONSISTENT'
   FLAG48  = 'COCAINE USE DATA INCONSISTENT'
   F_AGEGR2= 'IMPUTE FLAG FOR IAGEGRP2'
   F_RACETH= 'IMPUTE FLAG FOR I_RACETH'
   IAGEGRP2= 'AGE GROUP'
   PMOTHR  = 'CONDIT''L PROB OF SELECTING MOTHER (RIJ)'
   STRATUM = 'SAMPLING STRATUM'
   PHOSP   = 'PROB OF SELECTING HOSPITAL (PIJ)'
   DAYFCTR = 'DAY OF WEEK FACTOR (1/DIJK)'
   P       = 'PROB OF SELECT OF A MOTHER IN A HOSPITAL'
   STATUS  = 'SAQ RESPONSE STATUS'
   AELGFCTR= '1ST STAGE NONRESP ADJ FACTOR (AC1)'
   I_RACETH= 'RACE/ETHNICITY'
   NUMBABES= 'NUM OF LIVE BORN INFANTS DELIV. (BC3J)'
   NRFCTR  = '2ND STAGE NONRESP ADJ FACTOR (AC2)'
   NRWGT   = 'MOTHER WT AFTER 2ND STAGE NR ADJ'
   TRMADJMW= 'FINAL FULL SAMPLE WEIGHT SAQ'
   FMOTHWGT= 'FULL SAMPLE WEIGHT BLINDED URINE TESTS'
   TRMFCTR = 'TRIMMING ADJ FACTOR'
   ACTDAYS = 'ACTUAL DAYS IN HOSPITAL'
   BWGT    = 'MOTHER BASE WEIGHT'
   FACTOR  = 'POSTSTRAT (RAKING) ADJ FACTOR'
   FWGT    = 'WT REFLECT. # BABIES BORN, AFTER RAKING'
   RESP    = 'RESPONDENT TYPE'
   ALC3TUP = 'ALCOHOL 3RD TRIM (UPDATED)'
   ANY3TUP = 'ANY ILLICIT DRUG 3RD TRIM (UPDATED)'
   CIG3TUP = 'CIGARETTES 3RD TRIM (UPDATED)'
   COK3TUP = 'OTHER COCAINE 3RD TRIM (UPDATED)'
   COKA3TUP= 'ANY COCAINE 3RD TRIM (UPDATED)'
   CRK3TUP = 'CRACK 3RD TRIM (UPDATED)'
   DONE3TUP= 'METHADONE 3RD TRIM (UPDATED)'
   HER3TUP = 'HEROIN 3RD TRIM (UPDATED)'
   METH3TUP= 'METHAMPHETAMINE 3RD TRIM (UPDATED)'
   THC3TUP = 'MARIJUANA 3RD TRIM (UPDATED)'
   INCOME3 = 'HOUSEHOLD INCOME, 3 CATEGORIES'
   GAGEFLAG= 'FLAG FOR COMPUTED GESTATIONAL AGE'
   GAGE    = 'GESTATIONAL AGE'
   CIGPREG = 'CIGARETTE USE DURING PREGNANCY'
   ALCPREG = 'ALCOHOL USE DURING PREGNANCY'
   THCPREG = 'MARIJUANA USE DURING PREGNANCY'
   CRKPREG = 'CRACK USE DURING PREGNANCY'
   COKPREG = 'OTHER COCAINE DURING PREGNANCY'
   HERPREG = 'HEROIN USE DURING PREGNANCY'
   DONEPREG= 'METHADONE USE DURING PREGNANCY'
   METHPREG= 'METHAMPHETAMINE USE DURING PREGNANCY'
   ALLPREG = 'ANY ILLICIT DRUG USE DURING PREGNANCY'
   CIGEVER = 'EVER USE CIGARETTES'
   THCEVER = 'EVER USE MARIJUANA'
   COKEVER = 'EVER USE ANY COCAINE'
   RACETFLG= 'FLAG FOR IMPUTED RACE/ETHNICITY'
   PAYFLAG = 'FLAG FOR IMPUTED SOURCE OF PAYMENT'
   VSTSFLAG= 'FLAG FOR IMPUTED PRENATAL VISITS'
   METRO   = 'METRO STATUS OF HOSPITAL'
   EDUCFLAG= 'FLAG FOR IMPUTED MOTHER''S EDUCATION'
   EMPLFLAG= 'FLAG FOR IMPUTED EMPLOYMENT STATUS'
   RACEUP  = 'RACE/ETHNICITY'
   AGE5    = 'AGE GROUP, 5 CATEGORIES'
   AGE3    = 'AGE GROUP, 3 CATEGORIES'
   PAYUP   = 'SOURCE OF PAYMENT'
   MARITAL1= 'MARITAL STATUS (2 CATEGORIES)'
   MARITAL2= 'MARITAL STATUS (5 CATEGORIES)'
   EDUC    = 'MOTHER''S EDUCATION (4 CATEGORIES)'
   EDUC2   = 'MOTHER''S EDUCATION (2 CATEGORIES)'
   EMPL1   = 'MOTHERS EMPLOYMENT (2 LEVELS)'
   EMPL2   = 'MOTHERS EMPLOYMENT (5 LEVELS)'
   COKAPREG= 'ANY COCAINE DURING PREGNANCY'
   HALPREG = 'HALLUCINOGENS DURING PREGNANCY'
   INHPREG = 'INHALANTS DURING PREGNANCY'
   ILSEDA  = 'ILLICIT SEDATIVES IN PREG'
   ILTRANQ = 'ILLICIT TRANQ IN PREG'
   ILAMPHET= 'ILLICIT AMPHET IN PREG'
   ILANAL  = 'ILLICIT ANALGESICS IN PREG'
   ILPSY   = 'ILLICIT PSYCHOTHER IN PREG'
   SEDA    = 'SCRIP SEDATIVES IN PREG'
   TRANQ   = 'SCRIP TRANQ IN PREG'
   AMPHET  = 'SCRIP AMPHETAMINES IN PREG'
   ANAL    = 'SCRIP ANALGESICS IN PREGNANCY'
   SCRPSY  = 'SCRIP PSYCHOTHER IN PREG'
   CIGYR   = 'CIGARETTE USE PAST YEAR'
   ALCYR   = 'ALCOHOL USE PAST YEAR'
   THCYR   = 'MARIJUANA USE PAST YEAR'
   CRKYR   = 'CRACK USE PAST YEAR'
   COKYR   = 'OTHER COCAINE DURING PAST YEAR'
   HERYR   = 'HEROIN USE PAST YEAR'
   DONEYR  = 'METHADONE USE PAST YEAR'
   METHYR  = 'METHAMPHETAMINE USE PAST YEAR'
   COKAYR  = 'ANY COCAINE DURING PAST YEAR'
   ALLYR   = 'ANY ILLICIT DRUG USE PAST YEAR'
   ALCIG   = 'ALCOHOL/CIGARETTE USE IN PREG'
   ANY3M   = 'ANY ILLICIT DRUG 3 MONTHS PRIOR'
   THC3M   = 'MARIJUANA 3 MONTHS PRIOR'
   CRK3M   = 'CRACK 3 MONTHS PRIOR'
   COK3M   = 'OTHER COCAINE 3 MONTHS PRIOR'
   COKA3M  = 'ANY COCAINE 3 MONTHS PRIOR'
   HER3M   = 'HEROIN 3 MONTHS PRIOR'
   DONE3M  = 'METHADONE 3 MONTHS PRIOR'
   METH3M  = 'METHAMPHETAMINE 3 MONTHS PRIOR'
   ALC3M   = 'ALCOHOL 3 MONTHS PRIOR'
   CIG3M   = 'CIGARETTES 3 MONTHS PRIOR'
   ANY1T   = 'ANY ILLICIT DRUG 1ST TRIMESTER'
   THC1T   = 'MARIJUANA 1ST TRIMESTER'
   CRK1T   = 'CRACK 1ST TRIMESTER'
   COK1T   = 'OTHER COCAINE 1ST TRIMESTER'
   COKA1T  = 'ANY COCAINE 1ST TRIMESTER'
   HER1T   = 'HEROIN 1ST TRIMESTER'
   DONE1T  = 'METHADONE 1ST TRIMESTER'
   METH1T  = 'METHAMPHETAMINE 1ST TRIMESTER'
   ALC1T   = 'ALCOHOL 1ST TRIMESTER'
   CIG1T   = 'CIGARETTES 1ST TRIMESTER'
   ANY2T   = 'ANY ILLICIT DRUG 2ND TRIMESTER'
   THC2T   = 'MARIJUANA 2ND TRIMESTER'
   CRK2T   = 'CRACK 2ND TRIMESTER'
   COK2T   = 'OTHER COCAINE 2ND TRIMESTER'
   COKA2T  = 'ANY COCAINE 2ND TRIMESTER'
   HER2T   = 'HEROIN 2ND TRIMESTER'
   DONE2T  = 'METHADONE 2ND TRIMESTER'
   METH2T  = 'METHAMPHETAMINE 2ND TRIMESTER'
   ALC2T   = 'ALCOHOL 2ND TRIMESTER'
   CIG2T   = 'CIGARETTES 2ND TRIMESTER'
   ANY3D   = 'ANY ILLICIT DRUG LAST 3 DAYS'
   THC3D   = 'MARIJUANA LAST 3 DAYS'
   CRK3D   = 'CRACK LAST 3 DAYS'
   COK3D   = 'OTHER COCAINE LAST 3 DAYS'
   COKA3D  = 'ANY COCAINE LAST 3 DAYS'
   HER3D   = 'HEROIN LAST 3 DAYS'
   DONE3D  = 'METHADONE LAST 3 DAYS'
   METH3D  = 'METHAMPHETAMINE LAST 3 DAYS'
   ALC3D   = 'ALCOHOL LAST 3 DAYS'
   CIG3D   = 'CIGARETTES LAST 3 DAYS'
   CIG1TS  = 'CIGARETTES STOPPED TRIM 1'
   CIG3TC  = 'CIGARETTES CONTINUED TRIM 3'
   ALC1TS  = 'ALCOHOL STOPPED TRIM 1'
   ALC3TC  = 'ALC CONTINUED TRIM 3'
   NEWVOL  = 'URINE VOLUME (EDITED,RECODED)'
   COKES   = 'COCAINE SCREEN TEST'
   COKEQ   = 'COCAINE CONFIRM TEST QUAL'
   COKEN   = 'COCAINE CONFIRM TEST QUANT (NG/ML)'
   AMPHS   = 'AMPHET SCREEN TEST'
   AMPHQ   = 'AMPHET CONFIRM TEST QUAL'
   AMPHN   = 'AMPHET CONFIRM TEST QUANT (NG/ML)'
   METHQ   = 'METH CONFIRM QUAL'
   METHN   = 'METH CONFIRM QUANT (NG/ML)'
   THCS    = 'MARIJUANA SCREEN TEST'
   THCQ    = 'MARIJUANA CONFIRM TEST QUAL'
   THCN    = 'MARIJUANA CONFIRM TEST QUANT (NG/ML)'
   OPS     = 'OPIATE SCREEN'
   CODQ    = 'CODEINE CONFIRM TEST QUAL'
   CODN    = 'CODEINE CONFIRM TEST QUANT (NG/ML)'
   MORPHQ  = 'MORPHINE CONFIRM QUAL'
   MORPHN  = 'MORPHINE CONFIRM QUANT (NG/ML)'
   AMPHET3D= 'AMPHET LAST 3D'
   ANAL3D  = 'ANALGESICS LAST 3D'
   AMETH3D = 'AMPHET/METH LAST 3D'
   HANAL3D = 'HEROIN/ANALGESIC LAST 3D'
   THCTEST = 'MARIJUANA TEST RESULT (FINAL)'
   COKETEST= 'COCAINE TEST RESULT (FINAL)'
   AMPHTEST= 'AMPHET TEST RESULT (FINAL)'
   OPTEST  = 'OPIATE TEST RESULT'
   ANYTEST = 'ALL DRUGS TEST RESULT'
   THCRT   = 'MARIJUANA REPORT+NONBLTEST'
   COKERT  = 'COCAINE REPORT+NONBLTEST'
   SIZE    = 'HOSPITAL SIZE (ANNUAL BIRTHS)'
   TADJ1   = 'SAQ REPLICATE WEIGHT 1'
   TADJ2   = 'SAQ REPLICATE WEIGHT 2'
   TADJ3   = 'SAQ REPLICATE WEIGHT 3'
   TADJ4   = 'SAQ REPLICATE WEIGHT 4'
   TADJ5   = 'SAQ REPLICATE WEIGHT 5'
   TADJ6   = 'SAQ REPLICATE WEIGHT 6'
   TADJ7   = 'SAQ REPLICATE WEIGHT 7'
   TADJ8   = 'SAQ REPLICATE WEIGHT 8'
   TADJ9   = 'SAQ REPLICATE WEIGHT 9'
   TADJ10  = 'SAQ REPLICATE WEIGHT 10'
   TADJ11  = 'SAQ REPLICATE WEIGHT 11'
   TADJ12  = 'SAQ REPLICATE WEIGHT 12'
   TADJ13  = 'SAQ REPLICATE WEIGHT 13'
   TADJ14  = 'SAQ REPLICATE WEIGHT 14'
   TADJ15  = 'SAQ REPLICATE WEIGHT 15'
   TADJ16  = 'SAQ REPLICATE WEIGHT 16'
   TADJ17  = 'SAQ REPLICATE WEIGHT 17'
   TADJ18  = 'SAQ REPLICATE WEIGHT 18'
   INCOME  = 'HOUSEHOLD INCOME, 16 CATEGORIES'
   MULPREG2= 'MULTIPLE DRUG USE DURING PREGNANCY'
   AGE2    = 'AGE GROUP, 2 CATEGORIES'
   INCFLAG = 'FLAG FOR IMPUTED INCOME'
   PSU_VAR = 'PSU INDICATOR FOR VARIANCE EST.: 1-3'
   INT_FLG = 'INTERVIEW TIME < 30 MIN'
   INT_STAT= 'RESPONDENT INTERVIEW STATUS'
   SAQ_FLG = 'FLAG:SAQ TIME < 15 MIN'
   FILEIAQ = 'RECORD HAS IAQ DATA'
   FILERPTA= 'RECORD HAS RPTA DATA'
   FILESAQ = 'RECORD HAS SAQ DATA'
   FILEWTA = 'RECORD HAS WTA DATA'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (INT_TIME >= 9995) THEN INT_TIME = .;
   IF (IAQ_1 >= 95) THEN IAQ_1 = .;
   IF (IAQ_BOXA >= 6) THEN IAQ_BOXA = .;
   IF (IAQ_1A >= 6) THEN IAQ_1A = .;
   IF (IAQ_1B >= 96) THEN IAQ_1B = .;
   IF (IAQ_4 >= 96) THEN IAQ_4 = .;
   IF (IAQ_5 >= 995) THEN IAQ_5 = .;
   IF (IAQ5FLAG >= 6) THEN IAQ5FLAG = .;
   IF (IAQ_6 >= 96) THEN IAQ_6 = .;
   IF (IAQ6FLAG >= 6) THEN IAQ6FLAG = .;
   IF (IAQ_DAY >= 6) THEN IAQ_DAY = .;
   IF (IAQ_7 >= 6) THEN IAQ_7 = .;
   IF (IAQ_8 >= 96) THEN IAQ_8 = .;
   IF (IAQ8FLAG >= 6) THEN IAQ8FLAG = .;
   IF (IAQ_9 >= 96) THEN IAQ_9 = .;
   IF (IAQ_10 >= 95) THEN IAQ_10 = .;
   IF (IAQ_11 >= 96) THEN IAQ_11 = .;
   IF (IAQ_12A >= 6) THEN IAQ_12A = .;
   IF (IAQ_12B >= 6) THEN IAQ_12B = .;
   IF (IAQ_12C >= 6) THEN IAQ_12C = .;
   IF (IAQ_12D >= 6) THEN IAQ_12D = .;
   IF (IAQ_12E >= 6) THEN IAQ_12E = .;
   IF (IAQ_12F >= 6) THEN IAQ_12F = .;
   IF (IAQ_12G >= 6) THEN IAQ_12G = .;
   IF (IAQ_12H >= 6) THEN IAQ_12H = .;
   IF (IAQ_12HS >= 96) THEN IAQ_12HS = .;
   IF (IAQ_13A >= 6) THEN IAQ_13A = .;
   IF (IAQ_13B >= 6) THEN IAQ_13B = .;
   IF (IAQ_13C >= 6) THEN IAQ_13C = .;
   IF (IAQ_13D >= 6) THEN IAQ_13D = .;
   IF (IAQ_13DS >= 96) THEN IAQ_13DS = .;
   IF (IAQ_14 >= 6) THEN IAQ_14 = .;
   IF (IAQ_15 >= 995) THEN IAQ_15 = .;
   IF (IAQ_16 >= 995) THEN IAQ_16 = .;
   IF (IAQ_17FT >= 96) THEN IAQ_17FT = .;
   IF (IAQ_17IN >= 96) THEN IAQ_17IN = .;
   IF (IAQ_18A >= 6) THEN IAQ_18A = .;
   IF (IAQ_18B >= 6) THEN IAQ_18B = .;
   IF (IAQ_18C >= 6) THEN IAQ_18C = .;
   IF (IAQ_18D >= 6) THEN IAQ_18D = .;
   IF (IAQ_18DS >= 96) THEN IAQ_18DS = .;
   IF (IAQ_19A >= 6) THEN IAQ_19A = .;
   IF (IAQ_19B >= 6) THEN IAQ_19B = .;
   IF (IAQ_19C >= 6) THEN IAQ_19C = .;
   IF (IAQ_20A >= 6) THEN IAQ_20A = .;
   IF (IAQ_21A >= 6) THEN IAQ_21A = .;
   IF (IAQ_20B >= 6) THEN IAQ_20B = .;
   IF (IAQ_21B >= 6) THEN IAQ_21B = .;
   IF (IAQ_20C >= 6) THEN IAQ_20C = .;
   IF (IAQ_21C >= 6) THEN IAQ_21C = .;
   IF (IAQ_20D >= 6) THEN IAQ_20D = .;
   IF (IAQ_21D >= 6) THEN IAQ_21D = .;
   IF (IAQ_20E >= 6) THEN IAQ_20E = .;
   IF (IAQ_21E >= 6) THEN IAQ_21E = .;
   IF (IAQ_20F >= 6) THEN IAQ_20F = .;
   IF (IAQ_20SP >= 96) THEN IAQ_20SP = .;
   IF (IAQ_21F >= 6) THEN IAQ_21F = .;
   IF (IAQ_22 >= 6) THEN IAQ_22 = .;
   IF (IAQ_22SP >= 96) THEN IAQ_22SP = .;
   IF (IAQ_23 >= 96) THEN IAQ_23 = .;
   IF (IAQ_24A >= 96) THEN IAQ_24A = .;
   IF (IAQ_24B >= 96) THEN IAQ_24B = .;
   IF (IAQ_BOXB >= 6) THEN IAQ_BOXB = .;
   IF (IAQ_24C >= 96) THEN IAQ_24C = .;
   IF (IAQ_24D >= 96) THEN IAQ_24D = .;
   IF (IAQ_24E >= 96) THEN IAQ_24E = .;
   IF (IAQ_25 >= 6) THEN IAQ_25 = .;
   IF (IAQ_26 >= 96) THEN IAQ_26 = .;
   IF (IAQ26FLG >= 6) THEN IAQ26FLG = .;
   IF (IAQ_BOXC >= 6) THEN IAQ_BOXC = .;
   IF (IAQ_CNTR >= 96) THEN IAQ_CNTR = .;
   IF (IAQ_WG >= 96) THEN IAQ_WG = .;
   IF (IQ27LB01 >= 96) THEN IQ27LB01 = .;
   IF (IQ27LB02 >= 96) THEN IQ27LB02 = .;
   IF (IQ27LB03 >= 96) THEN IQ27LB03 = .;
   IF (IQ27LB04 >= 96) THEN IQ27LB04 = .;
   IF (IQ27LB05 >= 96) THEN IQ27LB05 = .;
   IF (IQ27LB06 >= 96) THEN IQ27LB06 = .;
   IF (IQ27LB07 >= 96) THEN IQ27LB07 = .;
   IF (IQ27LB08 >= 96) THEN IQ27LB08 = .;
   IF (IQ27LB09 >= 96) THEN IQ27LB09 = .;
   IF (IQ27LB10 >= 96) THEN IQ27LB10 = .;
   IF (IQ27OZ01 >= 96) THEN IQ27OZ01 = .;
   IF (IQ27OZ02 >= 96) THEN IQ27OZ02 = .;
   IF (IQ27OZ03 >= 96) THEN IQ27OZ03 = .;
   IF (IQ27OZ04 >= 96) THEN IQ27OZ04 = .;
   IF (IQ27OZ05 >= 96) THEN IQ27OZ05 = .;
   IF (IQ27OZ06 >= 96) THEN IQ27OZ06 = .;
   IF (IQ27OZ07 >= 96) THEN IQ27OZ07 = .;
   IF (IQ27OZ08 >= 96) THEN IQ27OZ08 = .;
   IF (IQ27OZ09 >= 96) THEN IQ27OZ09 = .;
   IF (IQ27OZ10 >= 96) THEN IQ27OZ10 = .;
   IF (IQ2801 >= 96) THEN IQ2801 = .;
   IF (IQ2802 >= 96) THEN IQ2802 = .;
   IF (IQ2803 >= 96) THEN IQ2803 = .;
   IF (IQ2804 >= 96) THEN IQ2804 = .;
   IF (IQ2805 >= 96) THEN IQ2805 = .;
   IF (IQ2806 >= 96) THEN IQ2806 = .;
   IF (IQ2807 >= 96) THEN IQ2807 = .;
   IF (IQ2808 >= 96) THEN IQ2808 = .;
   IF (IQ2809 >= 96) THEN IQ2809 = .;
   IF (IQ2810 >= 96) THEN IQ2810 = .;
   IF (IQ2901 >= 6) THEN IQ2901 = .;
   IF (IQ2902 >= 6) THEN IQ2902 = .;
   IF (IQ2903 >= 6) THEN IQ2903 = .;
   IF (IQ2904 >= 6) THEN IQ2904 = .;
   IF (IQ2905 >= 6) THEN IQ2905 = .;
   IF (IQ2906 >= 6) THEN IQ2906 = .;
   IF (IQ2907 >= 6) THEN IQ2907 = .;
   IF (IQ2908 >= 6) THEN IQ2908 = .;
   IF (IQ2909 >= 6) THEN IQ2909 = .;
   IF (IQ2910 >= 6) THEN IQ2910 = .;
   IF (IAQ_31 >= 96) THEN IAQ_31 = .;
   IF (IAQ_32 >= 6) THEN IAQ_32 = .;
   IF (IAQ_33 >= 6) THEN IAQ_33 = .;
   IF (IAQ_34 >= 6) THEN IAQ_34 = .;
   IF (IAQ_35 >= 96) THEN IAQ_35 = .;
   IF (IAQ_36 >= 96) THEN IAQ_36 = .;
   IF (IAQ_BOXD >= 6) THEN IAQ_BOXD = .;
   IF (IAQ_37 >= 6) THEN IAQ_37 = .;
   IF (IAQ_38 >= 96) THEN IAQ_38 = .;
   IF (IAQ_39 >= 6) THEN IAQ_39 = .;
   IF (IAQ_40 >= 6) THEN IAQ_40 = .;
   IF (IAQ_41 >= 96) THEN IAQ_41 = .;
   IF (IAQ_42 >= 96) THEN IAQ_42 = .;
   IF (IAQ_43A >= 6) THEN IAQ_43A = .;
   IF (IAQ_43B >= 6) THEN IAQ_43B = .;
   IF (IAQ_43C >= 6) THEN IAQ_43C = .;
   IF (IAQ_43D >= 6) THEN IAQ_43D = .;
   IF (IAQ_43E >= 6) THEN IAQ_43E = .;
   IF (IAQ_43F >= 6) THEN IAQ_43F = .;
   IF (IAQ_43G >= 6) THEN IAQ_43G = .;
   IF (IAQ_43H >= 6) THEN IAQ_43H = .;
   IF (IAQ_43I >= 6) THEN IAQ_43I = .;
   IF (IAQ_BOXE >= 6) THEN IAQ_BOXE = .;
   IF (IAQ_44 >= 6) THEN IAQ_44 = .;
   IF (IAQ_45 >= 6) THEN IAQ_45 = .;
   IF (IAQ_BOXF >= 6) THEN IAQ_BOXF = .;
   IF (IAQ_46 >= 17) THEN IAQ_46 = .;
   IF (IAQ_BOXG >= 6) THEN IAQ_BOXG = .;
   IF (IAQ_47 >= 17) THEN IAQ_47 = .;
   IF (IAQ_48 >= 6) THEN IAQ_48 = .;
   IF (IAQ_49 >= 995) THEN IAQ_49 = .;
   IF (IAQ49FLG >= 6) THEN IAQ49FLG = .;
   IF (IAQ_50A >= 6) THEN IAQ_50A = .;
   IF (IAQ_50AM >= 6) THEN IAQ_50AM = .;
   IF (IAQ_50B >= 6) THEN IAQ_50B = .;
   IF (IAQ_50BM >= 6) THEN IAQ_50BM = .;
   IF (IAQ_50C >= 6) THEN IAQ_50C = .;
   IF (IAQ_50CM >= 6) THEN IAQ_50CM = .;
   IF (IAQ_50D >= 6) THEN IAQ_50D = .;
   IF (IAQ_50DM >= 6) THEN IAQ_50DM = .;
   IF (IAQ_50E >= 6) THEN IAQ_50E = .;
   IF (IAQ_50EM >= 6) THEN IAQ_50EM = .;
   IF (IAQ_50F >= 6) THEN IAQ_50F = .;
   IF (IAQ_50FM >= 6) THEN IAQ_50FM = .;
   IF (IAQ_BOXH >= 6) THEN IAQ_BOXH = .;
   IF (IAQ_51A >= 6) THEN IAQ_51A = .;
   IF (IAQ_51AM >= 6) THEN IAQ_51AM = .;
   IF (IAQ_51B >= 6) THEN IAQ_51B = .;
   IF (IAQ_51BM >= 6) THEN IAQ_51BM = .;
   IF (IAQ_51C >= 6) THEN IAQ_51C = .;
   IF (IAQ_51CM >= 6) THEN IAQ_51CM = .;
   IF (IAQ_51D >= 6) THEN IAQ_51D = .;
   IF (IAQ_51DM >= 6) THEN IAQ_51DM = .;
   IF (IAQ_51E >= 6) THEN IAQ_51E = .;
   IF (IAQ_51EM >= 6) THEN IAQ_51EM = .;
   IF (IAQ_51F >= 6) THEN IAQ_51F = .;
   IF (IAQ_51FM >= 6) THEN IAQ_51FM = .;
   IF (SAQ_TIME >= 9995) THEN SAQ_TIME = .;
   IF (LANG >= 6) THEN LANG = .;
   IF (IAQ_D2 >= 96) THEN IAQ_D2 = .;
   IF (AGECALC >= 96) THEN AGECALC = .;
   IF (NEWLBS >= 96) THEN NEWLBS = .;
   IF (NEWOZS >= 96) THEN NEWOZS = .;
   IF (NEWGRAMS >= 9995) THEN NEWGRAMS = .;
   IF (IAQ_EC >= 995) THEN IAQ_EC = .;
   IF (INFNUM >= 6) THEN INFNUM = .;
   IF (NEWLBS2 >= 96) THEN NEWLBS2 = .;
   IF (NEWOZS2 >= 96) THEN NEWOZS2 = .;
   IF (NEWGRAM2 >= 9995) THEN NEWGRAM2 = .;
   IF (GHFLAG >= 6) THEN GHFLAG = .;
   IF (SAQ_1A >= 6) THEN SAQ_1A = .;
   IF (SAQ_1B >= 6) THEN SAQ_1B = .;
   IF (SAQ_1C >= 96) THEN SAQ_1C = .;
   IF (SAQ_1D >= 96) THEN SAQ_1D = .;
   IF (SAQ_2A >= 6) THEN SAQ_2A = .;
   IF (SAQ_2B >= 6) THEN SAQ_2B = .;
   IF (SAQ_2C >= 96) THEN SAQ_2C = .;
   IF (SAQ_2D >= 96) THEN SAQ_2D = .;
   IF (SAQ_3A >= 6) THEN SAQ_3A = .;
   IF (SAQ_3B >= 6) THEN SAQ_3B = .;
   IF (SAQ_3C >= 96) THEN SAQ_3C = .;
   IF (SAQ_3D >= 96) THEN SAQ_3D = .;
   IF (SAQ_4A >= 6) THEN SAQ_4A = .;
   IF (SAQ_4B >= 6) THEN SAQ_4B = .;
   IF (SAQ_4C >= 96) THEN SAQ_4C = .;
   IF (SAQ_4D >= 96) THEN SAQ_4D = .;
   IF (SAQ_5A >= 6) THEN SAQ_5A = .;
   IF (SAQ_5B >= 6) THEN SAQ_5B = .;
   IF (SAQ_5C >= 96) THEN SAQ_5C = .;
   IF (SAQ_5D >= 96) THEN SAQ_5D = .;
   IF (SAQ_6A >= 6) THEN SAQ_6A = .;
   IF (SAQ_6B >= 6) THEN SAQ_6B = .;
   IF (SAQ_6C >= 96) THEN SAQ_6C = .;
   IF (SAQ_6D >= 96) THEN SAQ_6D = .;
   IF (SAQ_7A >= 6) THEN SAQ_7A = .;
   IF (SAQ_7B >= 6) THEN SAQ_7B = .;
   IF (SAQ_7C >= 96) THEN SAQ_7C = .;
   IF (SAQ_7D >= 96) THEN SAQ_7D = .;
   IF (SAQ_8A >= 6) THEN SAQ_8A = .;
   IF (SAQ_8B >= 6) THEN SAQ_8B = .;
   IF (SAQ_8C >= 96) THEN SAQ_8C = .;
   IF (SAQ_8D >= 96) THEN SAQ_8D = .;
   IF (SAQ_9A >= 6) THEN SAQ_9A = .;
   IF (SAQ_9B >= 6) THEN SAQ_9B = .;
   IF (SAQ_9C >= 96) THEN SAQ_9C = .;
   IF (SAQ_9D >= 96) THEN SAQ_9D = .;
   IF (SAQ_10A >= 6) THEN SAQ_10A = .;
   IF (SAQ_10B >= 6) THEN SAQ_10B = .;
   IF (SAQ_10C >= 96) THEN SAQ_10C = .;
   IF (SAQ_10D >= 96) THEN SAQ_10D = .;
   IF (SAQ_11A >= 6) THEN SAQ_11A = .;
   IF (SAQ_11B >= 6) THEN SAQ_11B = .;
   IF (SAQ_11C >= 96) THEN SAQ_11C = .;
   IF (SAQ_11D >= 96) THEN SAQ_11D = .;
   IF (SAQ_12A >= 6) THEN SAQ_12A = .;
   IF (SAQ_12B >= 6) THEN SAQ_12B = .;
   IF (SAQ_12C >= 96) THEN SAQ_12C = .;
   IF (SAQ_12D >= 96) THEN SAQ_12D = .;
   IF (SAQ_13A >= 6) THEN SAQ_13A = .;
   IF (SAQ_13B >= 6) THEN SAQ_13B = .;
   IF (SAQ_13C >= 96) THEN SAQ_13C = .;
   IF (SAQ_13D >= 96) THEN SAQ_13D = .;
   IF (SAQ_14A >= 6) THEN SAQ_14A = .;
   IF (SAQ_14B >= 6) THEN SAQ_14B = .;
   IF (SAQ_14C >= 96) THEN SAQ_14C = .;
   IF (SAQ_14D >= 96) THEN SAQ_14D = .;
   IF (SAQ_15A >= 6) THEN SAQ_15A = .;
   IF (SAQ_15B >= 6) THEN SAQ_15B = .;
   IF (SAQ_15C >= 96) THEN SAQ_15C = .;
   IF (SAQ_15D >= 96) THEN SAQ_15D = .;
   IF (SAQ_16A >= 6) THEN SAQ_16A = .;
   IF (SAQ_16B >= 6) THEN SAQ_16B = .;
   IF (SAQ_16C >= 96) THEN SAQ_16C = .;
   IF (SAQ_16D >= 96) THEN SAQ_16D = .;
   IF (SAQ_17A >= 6) THEN SAQ_17A = .;
   IF (SAQ_17B >= 6) THEN SAQ_17B = .;
   IF (SAQ_17C >= 96) THEN SAQ_17C = .;
   IF (SAQ_17D >= 96) THEN SAQ_17D = .;
   IF (SAQ_18A >= 6) THEN SAQ_18A = .;
   IF (SAQ_18B >= 6) THEN SAQ_18B = .;
   IF (SAQ_18C >= 96) THEN SAQ_18C = .;
   IF (SAQ_18D >= 96) THEN SAQ_18D = .;
   IF (SAQ_19A >= 6) THEN SAQ_19A = .;
   IF (SAQ_19B >= 6) THEN SAQ_19B = .;
   IF (SAQ_19C >= 96) THEN SAQ_19C = .;
   IF (SAQ_19D >= 96) THEN SAQ_19D = .;
   IF (SAQ_20A >= 6) THEN SAQ_20A = .;
   IF (SAQ_20B >= 6) THEN SAQ_20B = .;
   IF (SAQ_20C >= 96) THEN SAQ_20C = .;
   IF (SAQ_20D >= 96) THEN SAQ_20D = .;
   IF (SAQ_21A >= 6) THEN SAQ_21A = .;
   IF (SAQ_21B >= 6) THEN SAQ_21B = .;
   IF (SAQ_21C >= 96) THEN SAQ_21C = .;
   IF (SAQ_21D >= 96) THEN SAQ_21D = .;
   IF (SAQ_22A >= 6) THEN SAQ_22A = .;
   IF (SAQ_22B >= 6) THEN SAQ_22B = .;
   IF (SAQ_22C >= 96) THEN SAQ_22C = .;
   IF (SAQ_22D >= 96) THEN SAQ_22D = .;
   IF (SAQ_23A >= 6) THEN SAQ_23A = .;
   IF (SAQ_23B >= 6) THEN SAQ_23B = .;
   IF (SAQ_23C >= 96) THEN SAQ_23C = .;
   IF (SAQ_23D >= 96) THEN SAQ_23D = .;
   IF (SAQ_24A >= 6) THEN SAQ_24A = .;
   IF (SAQ_24B >= 6) THEN SAQ_24B = .;
   IF (SAQ_24C >= 96) THEN SAQ_24C = .;
   IF (SAQ_24D >= 96) THEN SAQ_24D = .;
   IF (SAQ_25A >= 6) THEN SAQ_25A = .;
   IF (SAQ_25B >= 6) THEN SAQ_25B = .;
   IF (SAQ_25C >= 96) THEN SAQ_25C = .;
   IF (SAQ_25D >= 96) THEN SAQ_25D = .;
   IF (SAQ_26A >= 6) THEN SAQ_26A = .;
   IF (SAQ_26B >= 6) THEN SAQ_26B = .;
   IF (SAQ_26C >= 96) THEN SAQ_26C = .;
   IF (SAQ_26D >= 96) THEN SAQ_26D = .;
   IF (SAQ_27A >= 6) THEN SAQ_27A = .;
   IF (SAQ_27B >= 6) THEN SAQ_27B = .;
   IF (SAQ_27C >= 96) THEN SAQ_27C = .;
   IF (SAQ_27D >= 96) THEN SAQ_27D = .;
   IF (SAQ_28A >= 6) THEN SAQ_28A = .;
   IF (SAQ_28B >= 6) THEN SAQ_28B = .;
   IF (SAQ_28C >= 96) THEN SAQ_28C = .;
   IF (SAQ_28D >= 96) THEN SAQ_28D = .;
   IF (SAQ_29A >= 6) THEN SAQ_29A = .;
   IF (SAQ_29B >= 6) THEN SAQ_29B = .;
   IF (SAQ_29C >= 96) THEN SAQ_29C = .;
   IF (SAQ_29D >= 96) THEN SAQ_29D = .;
   IF (SAQ_30A >= 6) THEN SAQ_30A = .;
   IF (SAQ_30B >= 6) THEN SAQ_30B = .;
   IF (SAQ_30C >= 96) THEN SAQ_30C = .;
   IF (SAQ_30D >= 96) THEN SAQ_30D = .;
   IF (SAQ_31A >= 6) THEN SAQ_31A = .;
   IF (SAQ_31B >= 6) THEN SAQ_31B = .;
   IF (SAQ_31C >= 96) THEN SAQ_31C = .;
   IF (SAQ_31D >= 96) THEN SAQ_31D = .;
   IF (SAQ_32A >= 6) THEN SAQ_32A = .;
   IF (SAQ_32B >= 6) THEN SAQ_32B = .;
   IF (SAQ_32C >= 96) THEN SAQ_32C = .;
   IF (SAQ_32D >= 96) THEN SAQ_32D = .;
   IF (SAQ_33A >= 6) THEN SAQ_33A = .;
   IF (SAQ_33B >= 6) THEN SAQ_33B = .;
   IF (SAQ_33C >= 6) THEN SAQ_33C = .;
   IF (SAQ_33D >= 96) THEN SAQ_33D = .;
   IF (SAQ_33E >= 96) THEN SAQ_33E = .;
   IF (SAQ_34A >= 6) THEN SAQ_34A = .;
   IF (SAQ_34B >= 6) THEN SAQ_34B = .;
   IF (SAQ_34C >= 6) THEN SAQ_34C = .;
   IF (SAQ_34D >= 96) THEN SAQ_34D = .;
   IF (SAQ_34E >= 96) THEN SAQ_34E = .;
   IF (SAQ_35A >= 6) THEN SAQ_35A = .;
   IF (SAQ_35B >= 6) THEN SAQ_35B = .;
   IF (SAQ_35C >= 6) THEN SAQ_35C = .;
   IF (SAQ_35D >= 96) THEN SAQ_35D = .;
   IF (SAQ_35E >= 96) THEN SAQ_35E = .;
   IF (SAQ_36A >= 6) THEN SAQ_36A = .;
   IF (SAQ_36B >= 6) THEN SAQ_36B = .;
   IF (SAQ_36C >= 6) THEN SAQ_36C = .;
   IF (SAQ_36D >= 96) THEN SAQ_36D = .;
   IF (SAQ_36E >= 96) THEN SAQ_36E = .;
   IF (SAQ_37H >= 6) THEN SAQ_37H = .;
   IF (SAQ_37I >= 6) THEN SAQ_37I = .;
   IF (SAQ_38 >= 6) THEN SAQ_38 = .;
   IF (SAQ_39 >= 6) THEN SAQ_39 = .;
   IF (SAQ_43A >= 6) THEN SAQ_43A = .;
   IF (SAQ_43B >= 6) THEN SAQ_43B = .;
   IF (SAQ_43C >= 6) THEN SAQ_43C = .;
   IF (SAQ_43D >= 6) THEN SAQ_43D = .;
   IF (SAQ_43E >= 6) THEN SAQ_43E = .;
   IF (SAQ_43F >= 6) THEN SAQ_43F = .;
   IF (SAQ_43G >= 6) THEN SAQ_43G = .;
   IF (SAQ_43H >= 6) THEN SAQ_43H = .;
   IF (SAQ_43I >= 6) THEN SAQ_43I = .;
   IF (SAQ_43J >= 6) THEN SAQ_43J = .;
   IF (SAQ_43K >= 6) THEN SAQ_43K = .;
   IF (SAQ_43L >= 6) THEN SAQ_43L = .;
   IF (SAQ_44 >= 6) THEN SAQ_44 = .;
   IF (SAQ_45 = 0) THEN SAQ_45 = .;
   IF (SAQ_45 >= 95) THEN SAQ_45 = .;
   IF (SAQ_46 >= 6) THEN SAQ_46 = .;
   IF (SAQ_47 = 0) THEN SAQ_47 = .;
   IF (SAQ_47 >= 95) THEN SAQ_47 = .;
   IF (SAQ_48 >= 6) THEN SAQ_48 = .;
   IF (FLAG44 >= 6) THEN FLAG44 = .;
   IF (FLAG46 >= 6) THEN FLAG46 = .;
   IF (FLAG48 >= 6) THEN FLAG48 = .;
   IF (F_AGEGR2 >= 6) THEN F_AGEGR2 = .;
   IF (F_RACETH >= 6) THEN F_RACETH = .;
   IF (STRATUM >= 6) THEN STRATUM = .;
   IF (AELGFCTR >= 6) THEN AELGFCTR = .;
   IF (I_RACETH >= 6) THEN I_RACETH = .;
   IF (NUMBABES >= 6) THEN NUMBABES = .;
   IF (NRFCTR >= 6) THEN NRFCTR = .;
   IF (TRMFCTR >= 6.0000) THEN TRMFCTR = .;
   IF (RESP >= 6) THEN RESP = .;
   IF (ALC3TUP >= 6) THEN ALC3TUP = .;
   IF (ANY3TUP >= 6) THEN ANY3TUP = .;
   IF (CIG3TUP >= 6) THEN CIG3TUP = .;
   IF (COK3TUP >= 6) THEN COK3TUP = .;
   IF (COKA3TUP >= 6) THEN COKA3TUP = .;
   IF (CRK3TUP >= 6) THEN CRK3TUP = .;
   IF (DONE3TUP >= 6) THEN DONE3TUP = .;
   IF (HER3TUP >= 6) THEN HER3TUP = .;
   IF (METH3TUP >= 6) THEN METH3TUP = .;
   IF (THC3TUP >= 6) THEN THC3TUP = .;
   IF (INCOME3 >= 6) THEN INCOME3 = .;
   IF (GAGEFLAG >= 6) THEN GAGEFLAG = .;
   IF (GAGE >= 96) THEN GAGE = .;
   IF (CIGPREG >= 6) THEN CIGPREG = .;
   IF (ALCPREG >= 6) THEN ALCPREG = .;
   IF (THCPREG >= 6) THEN THCPREG = .;
   IF (CRKPREG >= 6) THEN CRKPREG = .;
   IF (COKPREG >= 6) THEN COKPREG = .;
   IF (HERPREG >= 6) THEN HERPREG = .;
   IF (DONEPREG >= 6) THEN DONEPREG = .;
   IF (METHPREG >= 6) THEN METHPREG = .;
   IF (ALLPREG >= 6) THEN ALLPREG = .;
   IF (CIGEVER >= 6) THEN CIGEVER = .;
   IF (THCEVER >= 6) THEN THCEVER = .;
   IF (COKEVER >= 6) THEN COKEVER = .;
   IF (RACETFLG >= 6) THEN RACETFLG = .;
   IF (PAYFLAG >= 6) THEN PAYFLAG = .;
   IF (VSTSFLAG >= 6) THEN VSTSFLAG = .;
   IF (METRO >= 6) THEN METRO = .;
   IF (EDUCFLAG >= 6) THEN EDUCFLAG = .;
   IF (EMPLFLAG >= 6) THEN EMPLFLAG = .;
   IF (RACEUP >= 6) THEN RACEUP = .;
   IF (AGE5 >= 6) THEN AGE5 = .;
   IF (AGE3 >= 6) THEN AGE3 = .;
   IF (PAYUP >= 6) THEN PAYUP = .;
   IF (MARITAL1 >= 6) THEN MARITAL1 = .;
   IF (MARITAL2 >= 6) THEN MARITAL2 = .;
   IF (EDUC >= 6) THEN EDUC = .;
   IF (EDUC2 >= 6) THEN EDUC2 = .;
   IF (EMPL1 >= 6) THEN EMPL1 = .;
   IF (EMPL2 >= 6) THEN EMPL2 = .;
   IF (COKAPREG >= 6) THEN COKAPREG = .;
   IF (HALPREG >= 6) THEN HALPREG = .;
   IF (INHPREG >= 6) THEN INHPREG = .;
   IF (ILSEDA >= 6) THEN ILSEDA = .;
   IF (ILTRANQ >= 6) THEN ILTRANQ = .;
   IF (ILAMPHET >= 6) THEN ILAMPHET = .;
   IF (ILANAL >= 6) THEN ILANAL = .;
   IF (ILPSY >= 6) THEN ILPSY = .;
   IF (SEDA >= 6) THEN SEDA = .;
   IF (TRANQ >= 6) THEN TRANQ = .;
   IF (AMPHET >= 6) THEN AMPHET = .;
   IF (ANAL >= 6) THEN ANAL = .;
   IF (SCRPSY >= 6) THEN SCRPSY = .;
   IF (CIGYR >= 6) THEN CIGYR = .;
   IF (ALCYR >= 6) THEN ALCYR = .;
   IF (THCYR >= 6) THEN THCYR = .;
   IF (CRKYR >= 6) THEN CRKYR = .;
   IF (COKYR >= 6) THEN COKYR = .;
   IF (HERYR >= 6) THEN HERYR = .;
   IF (DONEYR >= 6) THEN DONEYR = .;
   IF (METHYR >= 6) THEN METHYR = .;
   IF (COKAYR >= 6) THEN COKAYR = .;
   IF (ALLYR >= 6) THEN ALLYR = .;
   IF (ALCIG >= 6) THEN ALCIG = .;
   IF (ANY3M >= 6) THEN ANY3M = .;
   IF (THC3M >= 6) THEN THC3M = .;
   IF (CRK3M >= 6) THEN CRK3M = .;
   IF (COK3M >= 6) THEN COK3M = .;
   IF (COKA3M >= 6) THEN COKA3M = .;
   IF (HER3M >= 6) THEN HER3M = .;
   IF (DONE3M >= 6) THEN DONE3M = .;
   IF (METH3M >= 6) THEN METH3M = .;
   IF (ALC3M >= 6) THEN ALC3M = .;
   IF (CIG3M >= 6) THEN CIG3M = .;
   IF (ANY1T >= 6) THEN ANY1T = .;
   IF (THC1T >= 6) THEN THC1T = .;
   IF (CRK1T >= 6) THEN CRK1T = .;
   IF (COK1T >= 6) THEN COK1T = .;
   IF (COKA1T >= 6) THEN COKA1T = .;
   IF (HER1T >= 6) THEN HER1T = .;
   IF (DONE1T >= 6) THEN DONE1T = .;
   IF (METH1T >= 6) THEN METH1T = .;
   IF (ALC1T >= 6) THEN ALC1T = .;
   IF (CIG1T >= 6) THEN CIG1T = .;
   IF (ANY2T >= 6) THEN ANY2T = .;
   IF (THC2T >= 6) THEN THC2T = .;
   IF (CRK2T >= 6) THEN CRK2T = .;
   IF (COK2T >= 6) THEN COK2T = .;
   IF (COKA2T >= 6) THEN COKA2T = .;
   IF (HER2T >= 6) THEN HER2T = .;
   IF (DONE2T >= 6) THEN DONE2T = .;
   IF (METH2T >= 6) THEN METH2T = .;
   IF (ALC2T >= 6) THEN ALC2T = .;
   IF (CIG2T >= 6) THEN CIG2T = .;
   IF (ANY3D >= 6) THEN ANY3D = .;
   IF (THC3D >= 6) THEN THC3D = .;
   IF (CRK3D >= 6) THEN CRK3D = .;
   IF (COK3D >= 6) THEN COK3D = .;
   IF (COKA3D >= 6) THEN COKA3D = .;
   IF (HER3D >= 6) THEN HER3D = .;
   IF (DONE3D >= 6) THEN DONE3D = .;
   IF (METH3D >= 6) THEN METH3D = .;
   IF (ALC3D >= 6) THEN ALC3D = .;
   IF (CIG3D >= 6) THEN CIG3D = .;
   IF (CIG1TS >= 6) THEN CIG1TS = .;
   IF (CIG3TC >= 6) THEN CIG3TC = .;
   IF (ALC1TS >= 6) THEN ALC1TS = .;
   IF (ALC3TC >= 6) THEN ALC3TC = .;
   IF (NEWVOL >= 995) THEN NEWVOL = .;
   IF (COKES >= 6) THEN COKES = .;
   IF (COKEQ >= 6) THEN COKEQ = .;
   IF (COKEN = 6) THEN COKEN = .;
   IF (AMPHS >= 6) THEN AMPHS = .;
   IF (AMPHQ >= 6) THEN AMPHQ = .;
   IF (AMPHN >= 6) THEN AMPHN = .;
   IF (METHQ >= 6) THEN METHQ = .;
   IF (METHN = 6) THEN METHN = .;
   IF (THCS >= 6) THEN THCS = .;
   IF (THCQ >= 6) THEN THCQ = .;
   IF (THCN = 6) THEN THCN = .;
   IF (OPS >= 6) THEN OPS = .;
   IF (CODQ >= 6) THEN CODQ = .;
   IF (CODN = 6) THEN CODN = .;
   IF (MORPHQ >= 6) THEN MORPHQ = .;
   IF (MORPHN = 6) THEN MORPHN = .;
   IF (AMPHET3D >= 6) THEN AMPHET3D = .;
   IF (ANAL3D >= 6) THEN ANAL3D = .;
   IF (AMETH3D >= 6) THEN AMETH3D = .;
   IF (HANAL3D >= 6) THEN HANAL3D = .;
   IF (THCTEST >= 6) THEN THCTEST = .;
   IF (COKETEST >= 6) THEN COKETEST = .;
   IF (AMPHTEST >= 6) THEN AMPHTEST = .;
   IF (OPTEST >= 6) THEN OPTEST = .;
   IF (ANYTEST >= 6) THEN ANYTEST = .;
   IF (THCRT >= 6) THEN THCRT = .;
   IF (COKERT >= 6) THEN COKERT = .;
   IF (SIZE >= 6) THEN SIZE = .;
   IF (INCOME >= 96) THEN INCOME = .;
   IF (MULPREG2 >= 6) THEN MULPREG2 = .;
   IF (AGE2 >= 6) THEN AGE2 = .;
   IF (INCFLAG >= 6) THEN INCFLAG = .;
   IF (PSU_VAR >= 6) THEN PSU_VAR = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT INT_TIME int_time. IAQ_1 iaq_1fff. IAQ_BOXA iaq_boxa.
         IAQ_1A iaq_1a. IAQ_1B iaq_1b. IAQ_4 iaq_4fff.
         IAQ_5 iaq_5fff. IAQ5FLAG iaq5flag. IAQ_6 iaq_6fff.
         IAQ6FLAG iaq6flag. IAQ_DAY iaq_day. IAQ_7 iaq_7fff.
         IAQ_8 iaq_8fff. IAQ8FLAG iaq8flag. IAQ_9 iaq_9fff.
         IAQ_10 iaq_10ff. IAQ_11 iaq_11ff. IAQ_12A iaq_12a.
         IAQ_12B iaq_12b. IAQ_12C iaq_12c. IAQ_12D iaq_12d.
         IAQ_12E iaq_12e. IAQ_12F iaq_12f. IAQ_12G iaq_12g.
         IAQ_12H iaq_12h. IAQ_12HS iaq_12hs. IAQ_13A iaq_13a.
         IAQ_13B iaq_13b. IAQ_13C iaq_13c. IAQ_13D iaq_13d.
         IAQ_13DS iaq_13ds. IAQ_14 iaq_14ff. IAQ_15 iaq_15ff.
         IAQ_16 iaq_16ff. IAQ_17FT iaq_17ft. IAQ_17IN iaq_17in.
         IAQ_18A iaq_18a. IAQ_18B iaq_18b. IAQ_18C iaq_18c.
         IAQ_18D iaq_18d. IAQ_18DS iaq_18ds. IAQ_19A iaq_19a.
         IAQ_19B iaq_19b. IAQ_19C iaq_19c. IAQ_20A iaq_20a.
         IAQ_21A iaq_21a. IAQ_20B iaq_20b. IAQ_21B iaq_21b.
         IAQ_20C iaq_20c. IAQ_21C iaq_21c. IAQ_20D iaq_20d.
         IAQ_21D iaq_21d. IAQ_20E iaq_20e. IAQ_21E iaq_21e.
         IAQ_20F iaq_20f. IAQ_20SP iaq_20sp. IAQ_21F iaq_21f.
         IAQ_22 iaq_22ff. IAQ_22SP iaq_22sp. IAQ_23 iaq_23ff.
         IAQ_24A iaq_24a. IAQ_24B iaq_24b. IAQ_BOXB iaq_boxb.
         IAQ_24C iaq_24c. IAQ_24D iaq_24d. IAQ_24E iaq_24e.
         IAQ_25 iaq_25ff. IAQ_26 iaq_26ff. IAQ26FLG iaq26flg.
         IAQ_BOXC iaq_boxc. IAQ_CNTR iaq_cntr. IAQ_WG iaq_wg.
         IQ27LB01 iq27lb0f. IQ27LB02 iq27lb1f. IQ27LB03 iq27lb2f.
         IQ27LB04 iq27lb3f. IQ27LB05 iq27lb4f. IQ27LB06 iq27lb5f.
         IQ27LB07 iq27lb6f. IQ27LB08 iq27lb7f. IQ27LB09 iq27lb8f.
         IQ27LB10 iq27lb9f. IQ27OZ01 iq27oz0f. IQ27OZ02 iq27oz1f.
         IQ27OZ03 iq27oz2f. IQ27OZ04 iq27oz3f. IQ27OZ05 iq27oz4f.
         IQ27OZ06 iq27oz5f. IQ27OZ07 iq27oz6f. IQ27OZ08 iq27oz7f.
         IQ27OZ09 iq27oz8f. IQ27OZ10 iq27oz9f. IQ2801 iq2801ff.
         IQ2802 iq2802ff. IQ2803 iq2803ff. IQ2804 iq2804ff.
         IQ2805 iq2805ff. IQ2806 iq2806ff. IQ2807 iq2807ff.
         IQ2808 iq2808ff. IQ2809 iq2809ff. IQ2810 iq2810ff.
         IQ2901 iq2901ff. IQ2902 iq2902ff. IQ2903 iq2903ff.
         IQ2904 iq2904ff. IQ2905 iq2905ff. IQ2906 iq2906ff.
         IQ2907 iq2907ff. IQ2908 iq2908ff. IQ2909 iq2909ff.
         IQ2910 iq2910ff. IAQ_31 iaq_31ff. IAQ_32 iaq_32ff.
         IAQ_33 iaq_33ff. IAQ_34 iaq_34ff. IAQ_35 iaq_35ff.
         IAQ_36 iaq_36ff. IAQ_BOXD iaq_boxd. IAQ_37 iaq_37ff.
         IAQ_38 iaq_38ff. IAQ_39 iaq_39ff. IAQ_40 iaq_40ff.
         IAQ_41 iaq_41ff. IAQ_42 iaq_42ff. IAQ_43A iaq_43a.
         IAQ_43B iaq_43b. IAQ_43C iaq_43c. IAQ_43D iaq_43d.
         IAQ_43E iaq_43e. IAQ_43F iaq_43f. IAQ_43G iaq_43g.
         IAQ_43H iaq_43h. IAQ_43I iaq_43i. IAQ_BOXE iaq_boxe.
         IAQ_44 iaq_44ff. IAQ_45 iaq_45ff. IAQ_BOXF iaq_boxf.
         IAQ_46 iaq_46ff. IAQ_BOXG iaq_boxg. IAQ_47 iaq_47ff.
         IAQ_48 iaq_48ff. IAQ_49 iaq_49ff. IAQ49FLG iaq49flg.
         IAQ_50A iaq_50a. IAQ_50AM iaq_50am. IAQ_50B iaq_50b.
         IAQ_50BM iaq_50bm. IAQ_50C iaq_50c. IAQ_50CM iaq_50cm.
         IAQ_50D iaq_50d. IAQ_50DM iaq_50dm. IAQ_50E iaq_50e.
         IAQ_50EM iaq_50em. IAQ_50F iaq_50f. IAQ_50FM iaq_50fm.
         IAQ_BOXH iaq_boxh. IAQ_51A iaq_51a. IAQ_51AM iaq_51am.
         IAQ_51B iaq_51b. IAQ_51BM iaq_51bm. IAQ_51C iaq_51c.
         IAQ_51CM iaq_51cm. IAQ_51D iaq_51d. IAQ_51DM iaq_51dm.
         IAQ_51E iaq_51e. IAQ_51EM iaq_51em. IAQ_51F iaq_51f.
         IAQ_51FM iaq_51fm. SAQ_TIME saq_time. LANG lang.
         IAQ_D2 iaq_d2ff. AGECALC agecalc. NEWLBS newlbs.
         NEWOZS newozs. NEWGRAMS newgrams. IAQ_EC iaq_ec.
         INFNUM infnum. NEWLBS2 newlbs2f. NEWOZS2 newozs2f.
         NEWGRAM2 newgramf. GHFLAG ghflag. SAQ_1A saq_1a.
         SAQ_1B saq_1b. SAQ_1C saq_1c. SAQ_1D saq_1d.
         SAQ_2A saq_2a. SAQ_2B saq_2b. SAQ_2C saq_2c.
         SAQ_2D saq_2d. SAQ_3A saq_3a. SAQ_3B saq_3b.
         SAQ_3C saq_3c. SAQ_3D saq_3d. SAQ_4A saq_4a.
         SAQ_4B saq_4b. SAQ_4C saq_4c. SAQ_4D saq_4d.
         SAQ_5A saq_5a. SAQ_5B saq_5b. SAQ_5C saq_5c.
         SAQ_5D saq_5d. SAQ_6A saq_6a. SAQ_6B saq_6b.
         SAQ_6C saq_6c. SAQ_6D saq_6d. SAQ_7A saq_7a.
         SAQ_7B saq_7b. SAQ_7C saq_7c. SAQ_7D saq_7d.
         SAQ_8A saq_8a. SAQ_8B saq_8b. SAQ_8C saq_8c.
         SAQ_8D saq_8d. SAQ_9A saq_9a. SAQ_9B saq_9b.
         SAQ_9C saq_9c. SAQ_9D saq_9d. SAQ_10A saq_10a.
         SAQ_10B saq_10b. SAQ_10C saq_10c. SAQ_10D saq_10d.
         SAQ_11A saq_11a. SAQ_11B saq_11b. SAQ_11C saq_11c.
         SAQ_11D saq_11d. SAQ_12A saq_12a. SAQ_12B saq_12b.
         SAQ_12C saq_12c. SAQ_12D saq_12d. SAQ_13A saq_13a.
         SAQ_13B saq_13b. SAQ_13C saq_13c. SAQ_13D saq_13d.
         SAQ_14A saq_14a. SAQ_14B saq_14b. SAQ_14C saq_14c.
         SAQ_14D saq_14d. SAQ_15A saq_15a. SAQ_15B saq_15b.
         SAQ_15C saq_15c. SAQ_15D saq_15d. SAQ_16A saq_16a.
         SAQ_16B saq_16b. SAQ_16C saq_16c. SAQ_16D saq_16d.
         SAQ_17A saq_17a. SAQ_17B saq_17b. SAQ_17C saq_17c.
         SAQ_17D saq_17d. SAQ_18A saq_18a. SAQ_18B saq_18b.
         SAQ_18C saq_18c. SAQ_18D saq_18d. SAQ_19A saq_19a.
         SAQ_19B saq_19b. SAQ_19C saq_19c. SAQ_19D saq_19d.
         SAQ_20A saq_20a. SAQ_20B saq_20b. SAQ_20C saq_20c.
         SAQ_20D saq_20d. SAQ_21A saq_21a. SAQ_21B saq_21b.
         SAQ_21C saq_21c. SAQ_21D saq_21d. SAQ_22A saq_22a.
         SAQ_22B saq_22b. SAQ_22C saq_22c. SAQ_22D saq_22d.
         SAQ_23A saq_23a. SAQ_23B saq_23b. SAQ_23C saq_23c.
         SAQ_23D saq_23d. SAQ_24A saq_24a. SAQ_24B saq_24b.
         SAQ_24C saq_24c. SAQ_24D saq_24d. SAQ_25A saq_25a.
         SAQ_25B saq_25b. SAQ_25C saq_25c. SAQ_25D saq_25d.
         SAQ_26A saq_26a. SAQ_26B saq_26b. SAQ_26C saq_26c.
         SAQ_26D saq_26d. SAQ_27A saq_27a. SAQ_27B saq_27b.
         SAQ_27C saq_27c. SAQ_27D saq_27d. SAQ_28A saq_28a.
         SAQ_28B saq_28b. SAQ_28C saq_28c. SAQ_28D saq_28d.
         SAQ_29A saq_29a. SAQ_29B saq_29b. SAQ_29C saq_29c.
         SAQ_29D saq_29d. SAQ_30A saq_30a. SAQ_30B saq_30b.
         SAQ_30C saq_30c. SAQ_30D saq_30d. SAQ_31A saq_31a.
         SAQ_31B saq_31b. SAQ_31C saq_31c. SAQ_31D saq_31d.
         SAQ_32A saq_32a. SAQ_32B saq_32b. SAQ_32C saq_32c.
         SAQ_32D saq_32d. SAQ_33A saq_33a. SAQ_33B saq_33b.
         SAQ_33C saq_33c. SAQ_33D saq_33d. SAQ_33E saq_33e.
         SAQ_34A saq_34a. SAQ_34B saq_34b. SAQ_34C saq_34c.
         SAQ_34D saq_34d. SAQ_34E saq_34e. SAQ_35A saq_35a.
         SAQ_35B saq_35b. SAQ_35C saq_35c. SAQ_35D saq_35d.
         SAQ_35E saq_35e. SAQ_36A saq_36a. SAQ_36B saq_36b.
         SAQ_36C saq_36c. SAQ_36D saq_36d. SAQ_36E saq_36e.
         SAQ_37H saq_37h. SAQ_37I saq_37i. SAQ_38 saq_38ff.
         SAQ_39 saq_39ff. SAQ_43A saq_43a. SAQ_43B saq_43b.
         SAQ_43C saq_43c. SAQ_43D saq_43d. SAQ_43E saq_43e.
         SAQ_43F saq_43f. SAQ_43G saq_43g. SAQ_43H saq_43h.
         SAQ_43I saq_43i. SAQ_43J saq_43j. SAQ_43K saq_43k.
         SAQ_43L saq_43l. SAQ_44 saq_44ff. SAQ_45 saq_45ff.
         SAQ_46 saq_46ff. SAQ_47 saq_47ff. SAQ_48 saq_48ff.
         FLAG44 flag44ff. FLAG46 flag46ff. FLAG48 flag48ff.
         F_AGEGR2 f_agegrf. F_RACETH f_raceth. IAGEGRP2 iagegrpf.
         STRATUM stratum. STATUS status. I_RACETH i_raceth.
         NUMBABES numbabes. NRFCTR nrfctr. TRMFCTR trmfctr.
         RESP resp. ALC3TUP alc3tup. ANY3TUP any3tup.
         CIG3TUP cig3tup. COK3TUP cok3tup. COKA3TUP coka3tup.
         CRK3TUP crk3tup. DONE3TUP done3tup. HER3TUP her3tup.
         METH3TUP meth3tup. THC3TUP thc3tup. INCOME3 income3f.
         GAGEFLAG gageflag. GAGE gage. CIGPREG cigpreg.
         ALCPREG alcpreg. THCPREG thcpreg. CRKPREG crkpreg.
         COKPREG cokpreg. HERPREG herpreg. DONEPREG donepreg.
         METHPREG methpreg. ALLPREG allpreg. CIGEVER cigever.
         THCEVER thcever. COKEVER cokever. RACETFLG racetflg.
         PAYFLAG payflag. VSTSFLAG vstsflag. METRO metro.
         EDUCFLAG educflag. EMPLFLAG emplflag. RACEUP raceup.
         AGE5 age5ffff. AGE3 age3ffff. PAYUP payup.
         MARITAL1 maritalf. MARITAL2 marita0f. EDUC educ.
         EDUC2 educ2fff. EMPL1 empl1fff. EMPL2 empl2fff.
         COKAPREG cokapreg. HALPREG halpreg. INHPREG inhpreg.
         ILSEDA ilseda. ILTRANQ iltranq. ILAMPHET ilamphet.
         ILANAL ilanal. ILPSY ilpsy. SEDA seda.
         TRANQ tranq. AMPHET amphet. ANAL anal.
         SCRPSY scrpsy. CIGYR cigyr. ALCYR alcyr.
         THCYR thcyr. CRKYR crkyr. COKYR cokyr.
         HERYR heryr. DONEYR doneyr. METHYR methyr.
         COKAYR cokayr. ALLYR allyr. ALCIG alcig.
         ANY3M any3m. THC3M thc3m. CRK3M crk3m.
         COK3M cok3m. COKA3M coka3m. HER3M her3m.
         DONE3M done3m. METH3M meth3m. ALC3M alc3m.
         CIG3M cig3m. ANY1T any1t. THC1T thc1t.
         CRK1T crk1t. COK1T cok1t. COKA1T coka1t.
         HER1T her1t. DONE1T done1t. METH1T meth1t.
         ALC1T alc1t. CIG1T cig1t. ANY2T any2t.
         THC2T thc2t. CRK2T crk2t. COK2T cok2t.
         COKA2T coka2t. HER2T her2t. DONE2T done2t.
         METH2T meth2t. ALC2T alc2t. CIG2T cig2t.
         ANY3D any3d. THC3D thc3d. CRK3D crk3d.
         COK3D cok3d. COKA3D coka3d. HER3D her3d.
         DONE3D done3d. METH3D meth3d. ALC3D alc3d.
         CIG3D cig3d. CIG1TS cig1ts. CIG3TC cig3tc.
         ALC1TS alc1ts. ALC3TC alc3tc. NEWVOL newvol.
         COKES cokes. COKEQ cokeq. COKEN coken.
         AMPHS amphs. AMPHQ amphq. AMPHN amphn.
         METHQ methq. METHN methn. THCS thcs.
         THCQ thcq. THCN thcn. OPS ops.
         CODQ codq. CODN codn. MORPHQ morphq.
         MORPHN morphn. AMPHET3D amphet3d. ANAL3D anal3d.
         AMETH3D ameth3d. HANAL3D hanal3d. THCTEST thctest.
         COKETEST coketest. AMPHTEST amphtest. OPTEST optest.
         ANYTEST anytest. THCRT thcrt. COKERT cokert.
         SIZE size. INCOME income. MULPREG2 mulpregf.
         AGE2 age2ffff. INCFLAG incflag. INT_FLG int_flg.
         INT_STAT int_stat. SAQ_FLG saq_flg. FILEIAQ fileiaq.
         FILERPTA filerpta. FILESAQ filesaq. FILEWTA filewta.
          ;
*/

RUN ;
